import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets
import "../common/border" as Border
import "../common/Colors.js" as Colors
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/Common.js" as Common
import "../common/Stat.js" as Stat

Item
{
    id: aboutMain

    property variant context: AboutWindow
    property variant aboutFontStyles: Fonts.About{}

    Localizer { id: tr; scope: "About" }

    Item
    {
        id: aboutMainWindow
        objectName: "aboutMainWindow"

        anchors.fill: parent
        focus: true

        state: "Copyright"

        Image
        {
            id: aboutWindowFrame
            objectName: "aboutWindowFrame"

            anchors.fill: parent;
            source: "../common/images/about/about_window_frame.png"

            smooth: true
        }

        Item
        {
            id: aboutHeader
            objectName: "aboutHeader"

            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right

            height: 105

            Widgets.DPIScaler { changeHeight: true; }

            Item
            {
                id: aboutMode
                objectName: "aboutMode"

                anchors.top: parent.top
                anchors.left: parent.left
                anchors.right: parent.right

                height: 0

                Image
                {
                    id: aboutModeImage

					anchors.top: parent.top
					anchors.left: parent.left
					anchors.leftMargin: 18
					anchors.topMargin: 23

                    smooth: true

					source: aboutMainWindow.state == "Credits" ? "../common/images/about/about_team_kis.png" : "../common/images/about/about_title_kis.png"


                    Widgets.DPIScaler { changeSize: true; }
                }

                MouseArea
                {
                    id: aboutModeMouseArea

                    anchors.fill: aboutModeImage
                    hoverEnabled: true

                    Widgets.Clickable {}

                    onClicked:
                    {
                        aboutMainWindow.state = (aboutMainWindow.state == "Copyright" ? "Credits" : "Copyright");
                        Stat.onButtonClick(Common.buildDelegatelessPath(aboutMode) + "." + aboutMainWindow.state);
                    }
                }

                Widgets.DPIScaler { changeHeight: true; }
            }

            Row
            {
                id: aboutVersion
                objectName: "aboutVersion"

                anchors.top: aboutMode.bottom
				anchors.topMargin: 68
                anchors.bottom: parent.bottom
				anchors.horizontalCenter: parent.horizontalCenter
                width: 120
                spacing: 0
                Item
                {
                	width: (parent.width - aboutVersionText.width - aboutVersionHotFixText.paintedWidth) / 2
                	height: parent.height
                }
                Text
                {
                    id: aboutVersionText
					anchors.verticalCenter: parent.verticalCenter
                    font: aboutFontStyles.standardAboutFontBold
                    color: "white"
                    text: context.applicationVersion

                    Widgets.DPIScaler { changeSize: true; }
                }
                Text
                {
                    id: aboutVersionHotFixText
                    width: parent.width - aboutVersionText.width
					anchors.verticalCenter: parent.verticalCenter
	                elide: Text.ElideLeft

                    font: aboutFontStyles.standardAboutFontBold
                    color: "white"
                    text: context.applicationHotfix ? (" (" + context.applicationHotfix.split(".").pop() + ")") : ""

                    Widgets.DPIScaler { changeSize: true; }
                }

                Widgets.DPIScaler { changeHeight: true; }
            }
        }

        Image
        {
            id: aboutBody
            objectName: "aboutBody"

            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: aboutHeader.bottom

            height: 270

            Widgets.DPIScaler { changeHeight: true; }

            Rectangle
            {
                // Image needs to workaround flickable cliping bug

                id: copyrightAboutBody
                objectName: "copyrightAboutBody"
                visible: aboutMainWindow.state === "Copyright"
                color: "#fff1f1"

                anchors.fill: parent
                anchors.leftMargin: 10
                anchors.rightMargin: 10

                smooth: true

                Widgets.DPIScaler { changeHeight: true; }

                Item
                {
                    id: copyrightColumn

                    anchors.top: parent.top
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.leftMargin: 30 * dpiScaler.factor
                    anchors.rightMargin: 30 * dpiScaler.factor
                    anchors.topMargin: 28 * dpiScaler.factor

                    Widgets.DPIScaler { id: dpiScaler; changeAll: true; }

                    Text
                    {
                        id: copyrightText
                        anchors.left: parent.left
                        anchors.right: parent.right

                        font: aboutFontStyles.standardAboutFontBold

                        wrapMode: Text.WordWrap
                        text: tr.Localize("Copyright")
                        horizontalAlignment: Text.AlignLeft

                        Widgets.DPIScaler { changeHeight: true; }
                    }

                    Text
                    {
                        id: copyrightWarning2Text
                        anchors.top: copyrightText.bottom
                        anchors.topMargin: 15 * dpiScaler.factor
                        anchors.left: parent.left
                        anchors.right: parent.right

                        font: aboutFontStyles.standardAboutFont
                        wrapMode: Text.WordWrap
                        horizontalAlignment: Text.AlignLeft

                        text: tr.Localize("Warning2")

                        Widgets.DPIScaler { changeHeight: true; }
                    }

					Text
                    {
                        id: copyrightWarning3Text
                        anchors.top: copyrightWarning2Text.bottom
                        anchors.topMargin: 12
                        anchors.left: parent.left
                        anchors.right: parent.right

                        font: aboutFontStyles.standardAboutFont
                        wrapMode: Text.WordWrap
                        horizontalAlignment: Text.AlignLeft

                        text: tr.Localize("Warning3")

                        Widgets.DPIScaler { changeHeight: true; }
                    }
					
					Text
                    {
                        id: copyrightSkinVersText
                        anchors.top: copyrightWarning3Text.bottom
                        anchors.topMargin: 32
						anchors.horizontalCenter: parent.horizontalCenter

                        font: aboutFontStyles.standardAboutFontBold
                        wrapMode: Text.WordWrap

                        text: '** Skin Special Ferrari Edition v2.0 **'

                        Widgets.DPIScaler { changeHeight: true; }
                    }
					
					Text
                    {
                        id: copyrightAuthorText
                        anchors.top: copyrightSkinVersText.bottom
                        anchors.topMargin: 15
                        anchors.left: parent.left
                        anchors.right: parent.right

                        font: aboutFontStyles.standardAboutFont
                        wrapMode: Text.WordWrap
                        horizontalAlignment: Text.AlignLeft
						
                        text: 'By : Nuk3'

                        Widgets.DPIScaler { changeHeight: true; }
                    }
			
					Text
                    {
                        id: copyrightThanxText
                        anchors.top: copyrightAuthorText.bottom
                        anchors.topMargin: 2
                        anchors.left: parent.left
                        anchors.right: parent.right

                        font: aboutFontStyles.standardAboutFont
                        wrapMode: Text.WordWrap
                        horizontalAlignment: Text.AlignLeft

                        text: 'Special Thx : tistou77 - harlan4096 - Parafulmine - Viktor - tommyktlab'

                        Widgets.DPIScaler { changeHeight: true; }
                    }
					
					Text
                    {
                        id: copyrightThanxPersText
                        anchors.top: copyrightThanxText.bottom
                        anchors.topMargin: 2
                        anchors.left: parent.left
                        anchors.right: parent.right

                        font: aboutFontStyles.standardAboutFont
                        wrapMode: Text.WordWrap
                        horizontalAlignment: Text.AlignLeft

                        text: 'All my friends : Thanks for the support !'

                        Widgets.DPIScaler { changeHeight: true; }
                    }
                }
            }

            MouseArea
            {
                id: aboutClickableMouseArea

                anchors.fill: parent

                hoverEnabled: true
                enabled: aboutMainWindow.state === "Credits"
                visible: aboutMainWindow.state === "Credits"

                Widgets.Clickable {}

                AboutCredits
                {
                    id: creditsAboutBody
                    objectName: "creditsAboutBody"

                    visible: aboutMainWindow.state === "Credits"

                    anchors.fill: parent
                    anchors.leftMargin: 30 * dpiScaler.factor
                    anchors.rightMargin: 30 * dpiScaler.factor

                    text: tr.Localize("Credits");
                }

                BorderImage
                {
                    source: "../common/images/about/fade_top.png"
                    anchors.top: parent.top
                    anchors.horizontalCenter: parent.horizontalCenter
                    height: sourceSize.height/2
                    width: parent.width - 20
                }

                BorderImage
                {
                    source: "../common/images/about/fade_bottom.png"
                    anchors.bottom: parent.bottom
                    anchors.horizontalCenter: parent.horizontalCenter
                    height: sourceSize.height/2
                    width: parent.width - 20
                }
            }
        }

        Column
        {
            id: aboutSeparator

            anchors.verticalCenter: aboutBody.bottom
            anchors.left: parent.left
            anchors.leftMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: 9

            height: childrenRect.height

            Rectangle
            {
                height: 1
                width: parent.width
                color: "#D7D7D7"
            }

            Rectangle
            {
                height: 1
                width: parent.width
                color: "#FFFFFF"
            }
        }

        Item
        {
            id: aboutFooter
            objectName: "aboutFooter"

            anchors.top: aboutSeparator.bottom
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            anchors.right: parent.right

            Widgets.GrayButton
            {
                id: aboutCloseButton
                setAsDefaultButton: true
                objectName: "CloseButton"
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -6
                anchors.horizontalCenter: parent.horizontalCenter
                text: tr.Localize("CloseButton")
                minWidth: 100

                onClicked: Window.Close();

                Widgets.DPIScaler { changeHeight: true; }
            }
        }

        states: [
            State {
                name: "Copyright"
            },
            State {
                name: "Credits"
            }
        ]

        Keys.onPressed:
        {
            if (event.key === Qt.Key_Space)
            {
                aboutMainWindow.state = (aboutMainWindow.state == "Copyright" ? "Credits" : "Copyright");
            }
        }
    }
}

