import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/EnumHelper.js" as EnumHelper
import "../common/Margins.js" as Margins
import "../common/HelpMapper.js" as HelpMapper

ActivationBasePage
{
	Localizer { id:tr; scope:"LicenseManager" }
	headerString:			tr.Localize("ActivationResultConnectionErrorHeader")
	objectName: "ActivationResultConnectionErrorHeader"
	nextButtonEnabled:		context.ActivationPageNoConnection.IsNextEnabled

	function getHelpId()
	{
        return HelpMapper.ActivationPageNoConnectionHelpId;
	}

	Column
	{
		anchors.fill:	parent
		objectName: "column"
		Column
		{
			spacing:	10
			anchors.left:	parent.left
			anchors.right:	parent.right
			objectName: "column"
			Text
			{
				id:				textForCheckInternetAndTryingActivation
				objectName: "textForCheckInternetAndTryingActivation"
				anchors.left:	parent.left
				anchors.right:	parent.right
				text:			tr.Localize("TextForCheckInternetAndTryingActivation")
				font:			activationWizard.fontStyles.masterOfActivationButtonsNormalText
				wrapMode:		Text.Wrap
				horizontalAlignment: Text.AlignLeft
			}
            Widgets.GrayButton
			{
				id:						buttonForCheckInternetAndTryingActivation
				objectName: "buttonForCheckInternetAndTryingActivation"
				text:					tr.Localize("ButtonTextForCheckInternetAndTryingActivation")
				anchors.left:	parent.left
				onClicked: 
				{
					context.TryActivation();
				}
			}
		}
		Item { width: parent.width; height: 25 }
		Rectangle{width: workingArea.width; x: -pagesWorkingArea.anchors.leftMargin; height: 1; color: "#cccccc";}
		Item { width: parent.width; height: 30 }

		Column
		{
			spacing:	6
			anchors.left:	parent.left
			anchors.right:	parent.right
			Text
			{
				id:				textForActivationWithKeyFile
				objectName: "textForActivationWithKeyFile"
				anchors.left:	parent.left
				text:			tr.Localize("TextForActivationWithKeyFile")
				font:			activationWizard.fontStyles.textForActivationWithKeyFile
				wrapMode:		Text.Wrap
				horizontalAlignment: Text.AlignLeft
			}
			Column
			{
				anchors.left:	parent.left
				anchors.right:	parent.right
				spacing: 		3
				Text
				{
					objectName: "descriptionForActivationWithKeyFile"
					anchors.left:	parent.left
					anchors.right:	parent.right
					height:			paintedHeight
					text:			tr.Localize("DescriptionForActivationWithKeyFile")
					font:			activationWizard.fontStyles.masterOfActivationButtonsNormalText
					wrapMode:		Text.Wrap
					horizontalAlignment: Text.AlignLeft

					onLinkActivated:
					{
                        Window.OpenURL(context.ActivationPageNoConnection.activationCenterLink);
					}
				}
			}
		}
		Item { width: parent.width; height: 18 }
		Column
		{
			anchors.left:	parent.left
			width:	parent.width
			objectName: "column"
			spacing: 10
			Text
			{
				id:				activationKeyFileText
				objectName: "activationKeyFileText"
				anchors.left:	parent.left
				text:			tr.Localize("ActivationKeyFileText")
				font:			activationWizard.fontStyles.masterOfActivationButtonsNormalText
				horizontalAlignment: Text.AlignLeft
			}
			Item
			{
				anchors.left:				parent.left
				anchors.right:				parent.right
				height:						childrenRect.height
				objectName: "browseKeyFile"
				Rectangle
				{
					id:				activationKeyFile
					border.color:	"gray"
					anchors.left:	parent.left
					anchors.right:	buttonForBrowseKeyFile.left
					anchors.rightMargin:		Margins.horizontalBetweenButtons
					radius: 3
					height: 28
					Text
					{
						id: activationKeyFileName
						objectName: "activationKeyFileName"
						anchors.fill: parent
						anchors.leftMargin: 6
						anchors.rightMargin: 6
						text:			context.KeyFilePath
						font: activationWizard.fontStyles.activationKeyFileInput
						verticalAlignment: Text.AlignVCenter
						elide: Text.ElideMiddle
						color: "gray"
						horizontalAlignment: Text.AlignLeft
					}
				}
                Widgets.GrayButton
				{
					id:						buttonForBrowseKeyFile
					objectName: "buttonForBrowseKeyFile"
					anchors.right:			parent.right
					text:					tr.Localize("ButtonTextForBrowseKeyFile")
					onClicked:
					{
						context.KeyFilePath = context.ActivationPageNoConnection.BrowseKeyFile();
					}
				}
			}
		}
	}
}

