import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/EnumHelper.js" as EnumHelper
import "../common/DateTime.js" as DateTime

ActivationBasePage
{
	Localizer { id:tr; scope:"LicenseManager" }
	headerString:			tr.Localize("ActivationResultSucceedHeader")
	nextButtonText:			tr.Localize("ButtonFinishText")
	helpButtonVisible: 	false
	objectName: "activationPageSucceeded"

	Column
	{
		anchors.left:				parent.left
		anchors.right:				parent.right
		anchors.verticalCenter:		parent.verticalCenter
        anchors.verticalCenterOffset: -25
		spacing:					15
		AnimatedImage
		{
			anchors.horizontalCenter:		parent.horizontalCenter
            source:							"../common/images/license/ico_ok_150.png"
		}
		Text
		{
			objectName: "successDescriptionText"
			horizontalAlignment:			Text.AlignHCenter
			anchors.left:					parent.left
			property int margins: 			50
			anchors.leftMargin:				margins
			anchors.rightMargin: 			margins
			anchors.right:					parent.right
			wrapMode:						Text.Wrap
			anchors.topMargin:				10
			
			function getSuccessDescription()
			{
				var key = "ActivationSuccessfullyCompleted"
                if(context !== undefined)
				{
                    switch(EnumHelper.getKey(context, "ActivationType"))
				    {
				    case "AddLicense":			key = "AddCodeToReserveSuccessfullyCompleted";	break;
				    case "CheckReserveCode":	key = "CheckReserveCodeSuccessfullyCompleted";	break;
				    case "SubscriptionUpdate":	key = "SubscriptionStatusSuccessfullyUpdated";	break;
					case "DelayedRegistration": key = "RegistrationCompleted";	break;
					case "InProductPurchasing": 
						key = (context.IsActivationAvailable() ? "CodeUsefullInFuture" : "CodeUsefullInFutureErr"); break;
					
				    }
                }
				return tr.Localize(key);
			}
			text:							getSuccessDescription()
			font:							activationWizard.fontStyles.stateTextForActivationResult
		}
	}

	function onNext()
	{
		console.log("activationPageSucceeded::onNext(finished)");
		activationWizard.cancel();
	}
}

