import QtQuick 1.1
import "../fonts" as Fonts

BaseButton
{
	id: button
	objectName: "button"

	property bool setAsDefaultButton: false;

	property variant fontStyles: Fonts.Common{}

	focusRectTarget: (focusRectEnabled && backgroundImage) ? button : undefined
	property string text: ""
	property alias textfont:			buttonText.font
	property alias textStyle:			buttonText.style
	property alias textStyleColor:		buttonText.styleColor
	property variant textcolor:			"White"
	property variant textcolorHovered:	""
	property variant textcolorPressed:	""
	property variant textcolorDisabled:	"Gray"
    property int textWidth

	property string backgroundImage:	""
    property string hoverImage
	property string pressedImage
	property string disabledImage

	property string defaultButtonEffectImage

	property string iconImage:			""
    property string iconHoverImage
	property string iconPressedImage
	property string iconDisabledImage

	property string hoverEffectImage
	property string pressedEffectImage
	property string disabledEffectImage

	property int borderWidth:			(buttonText.paintedWidth && backgroundImage) ? 5 : 0
	property int borderLeft: 			borderWidth
	property int borderRight: 			borderWidth
    property int horizontalTileMode:    BorderImage.Stretch
    property int verticalTileMode:      BorderImage.Stretch
	property int horizontalMargin: 		(buttonText.paintedWidth && backgroundImage) ? 5 : 0
    property int rightMargin:           0
    property int leftMargin:           0
	property int verticalMargin: 		(buttonText.paintedWidth && backgroundImage) ? 5 : 0
	property int spacing:				(buttonText.paintedWidth && icon.width) ? 5 : 0
	property real textVerticalOffset: 1

	property int minWidth
	property int maxWidth

	property int minHeight
	property int maxHeight

	property int buttonWidth
	property int buttonHeight

	property bool textBottom
	property bool textLeft
    property bool mirror: false
	property bool mirrorBackground: mirror
    property bool mirrorIcon: mirror

	property bool dpiScale: true

	HotKeyParser
	{
		id: hotKeyParser
		text: button.text
	}
	HotKey
	{
		text: hotKeyParser.hotKeyText
		onPressed: click()
	}

	function getSize(minSize, maxSize, textSize)
	{
		return Math.max(minSize, Math.min(textSize, maxSize ? maxSize : textSize));
	}
	function getAndUpdateWidthForTextRigth()
	{
        var marginWidth		= horizontalMargin * 2 + (icon.width ? spacing : 0) + leftMargin + rightMargin;
		var widthForItems	= buttonText.paintedWidth + icon.width + marginWidth;
		var localWidth		= buttonWidth ? buttonWidth : getSize(minWidth, maxWidth, widthForItems);

		if (localWidth < widthForItems)
		{
			buttonText.width = localWidth - marginWidth - icon.width;
			widthForItems	= buttonText.paintedWidth + icon.width + marginWidth;
		}

		if (icon.width)
		{
            icon.anchors.leftMargin = textLeft ? horizontalMargin : Math.abs(localWidth - widthForItems)/2 + horizontalMargin;
			buttonText.anchors.leftMargin = spacing;
		}
		else
        {
			icon.anchors.leftMargin = 0;
            buttonText.anchors.leftMargin = textLeft ? horizontalMargin + leftMargin : Math.abs(localWidth - widthForItems)/2 + horizontalMargin ;
        }

		return localWidth;
	}

	function getAndUpdateHeightForTextRigth()
	{
		var marginHeight	= verticalMargin * 2;
		var heightForItems	= Math.max(buttonText.text ? buttonText.paintedHeight : 0, icon.height) + marginHeight;
		var localHeight		= buttonHeight ? buttonHeight : getSize(minHeight, maxHeight, heightForItems);

		return localHeight;
	}

	function getAndUpdateWidthForTextBottom()
	{
		var marginWidth = horizontalMargin * 2;
		var widthForItems = Math.max(buttonText.paintedWidth, icon.width) + marginWidth;
		var localWidth = buttonWidth ? buttonWidth : getSize(minWidth, maxWidth, widthForItems);

		return localWidth;
	}

	function getAndUpdateHeightForTextBottom()
	{
		var marginHeight = verticalMargin * 2 + (icon.height ? spacing : 0);
		var heightForItems = buttonText.paintedHeight + icon.height + marginHeight;
		var localHeight = buttonHeight ? buttonHeight : getSize(minHeight, maxHeight, heightForItems);

		if (icon.height)
		{
			icon.anchors.topMargin = Math.abs(localHeight - heightForItems)/2 + verticalMargin;
			buttonText.anchors.topMargin = spacing;
		}
		else
		{
			icon.anchors.topMargin = 0;
			buttonText.anchors.topMargin = Math.abs(localHeight - heightForItems) / 2 + verticalMargin;
		}

		return localHeight;
	}

	width: button.textBottom ? getAndUpdateWidthForTextBottom() : getAndUpdateWidthForTextRigth()
	height: button.textBottom ? getAndUpdateHeightForTextBottom() : getAndUpdateHeightForTextRigth()

	BorderImage
	{
		anchors.fill: parent
		source:	button.selectValue(button.disabledImage, button.backgroundImage, button.hoverImage, button.pressedImage)
		border { left: button.borderLeft; top: button.borderWidth; right: button.borderRight; bottom: button.borderWidth }
        horizontalTileMode: button.horizontalTileMode
        verticalTileMode: button.verticalTileMode
		mirror: button.mirrorBackground
	}
	BorderImage
	{
		anchors.fill: parent
		visible: button.activeFocus || (isRegisteredAsDefaultButton() && !viewHasFocusedButton())
		source:	defaultButtonEffectImage ? defaultButtonEffectImage : ""
		border { left: button.borderLeft; top: button.borderWidth; right: button.borderRight; bottom: button.borderWidth }
		mirror: button.mirrorBackground
		opacity: selectValue(0, 1, 0.1, 0.1)
	}

	BorderImage
	{
        id:				hoverEffect
        anchors.verticalCenter: 	parent.verticalCenter
        anchors.horizontalCenter: parent.horizontalCenter
        width:          Math.max(sourceSize.width, parent.width)
        height:         Math.max(sourceSize.height, parent.height)
		source:			hoverEffectImage ? hoverEffectImage : ""
		visible:		selectValue(false, false, true, false)
	}
	BorderImage
	{
		id:				pressedEffect
		anchors.fill:	parent
		source:			pressedEffectImage ? pressedEffectImage : ""
		visible:		selectValue(false, false, false, true)
	}
	BorderImage
	{
		id:				disabledEffect
		anchors.fill:	parent
		source:			disabledEffectImage ? disabledEffectImage : ""
		visible:		!button.enabled
	}

	Image
	{
		id:					icon

        smooth: true
		DPIScaler {changeSize: button.dpiScale}
		FocusRect
		{
			target: (buttonText.text || button.focusRectTarget || !button.focusRectEnabled) ? undefined : button
			anchors.topMargin: 2
			anchors.bottomMargin: 3
			anchors.rightMargin: 3
			anchors.leftMargin: 2
		}

		source:				selectValue(button.iconDisabledImage, button.iconImage, button.iconHoverImage, button.iconPressedImage)
		anchors.left:		button.textBottom ? undefined : parent.left
		anchors.top:		button.textBottom ? parent.top : undefined
		anchors.verticalCenter: button.textBottom ? undefined : parent.verticalCenter
		anchors.horizontalCenter: button.textBottom ? parent.horizontalCenter : undefined
		mirror: button.mirrorIcon
	}
	

	Text
	{
		FocusRect
		{
			target: (button.focusRectTarget || !button.focusRectEnabled || !buttonText.text)  ? undefined : button
			anchors.topMargin: 0
			anchors.bottomMargin: 1
			anchors.rightMargin: 0
			anchors.leftMargin: -2
		}
		id:		buttonText
		text: hotKeyParser.textToShow
		font:		button.fontStyles.standardButtonFont
        elide:		Text.ElideRight
        width:      textWidth ? textWidth : undefined
		color:		selectValue(textcolorDisabled, textcolor, textcolorHovered, textcolorPressed)
		verticalAlignment:	Text.AlignVCenter
        horizontalAlignment:	button.textLeft ? Text.AlignLeft : Text.AlignHCenter
		anchors.left:
		{
			if (button.textBottom)
				return undefined;
			if (icon.source && icon.source != "")
				return icon.right
            if (leftMargin > 0 || rightMargin > 0)
                return parent.left
			else
				return undefined
		}
		anchors.top:		button.textBottom ? icon.bottom : undefined
		anchors.verticalCenter: button.textBottom ? undefined : parent.verticalCenter
        anchors.verticalCenterOffset: button.textVerticalOffset
		anchors.horizontalCenter:
		{
			if (button.textBottom)
				return parent.horizontalCenter
			if (icon.source && icon.source != "")
				return undefined
            if (leftMargin > 0 || rightMargin > 0)
                return undefined
			else
				return parent.horizontalCenter
		}
	}

	function registerAsDefaultButton(doRegister)
	{
		if (!defaultButtonManager)
			return;

		if (doRegister)
			defaultButtonManager.register(button);
		else
			defaultButtonManager.deregister(button);
	}

	function updateStateAsDefaultButton()
	{
		var enabledAsDefaultButton = visible && enabled;
		if (setAsDefaultButton && enabledAsDefaultButton && !isRegisteredAsDefaultButton())
			registerAsDefaultButton(true);
		else if (isRegisteredAsDefaultButton() && (!setAsDefaultButton || !enabledAsDefaultButton))
			registerAsDefaultButton(false);
	}
	function isRegisteredAsDefaultButton()
	{
		return (defaultButtonManager != undefined) && defaultButtonManager.isRegistered(button);
	}
	function viewHasFocusedButton()
	{
		return (defaultButtonManager != undefined) && defaultButtonManager.focusButtonRegistered();
	}
	function registerFocusedState(doRegister)
	{
		if (defaultButtonManager != undefined)
		{
			if (doRegister)
				defaultButtonManager.registerFocusedButton(button);
			else
				defaultButtonManager.deregisterFocusedButton(button);
		}
	}
	function updateFocusState()
	{
		if (activeFocus && enabled && visible)
			registerFocusedState(true);
		else
			registerFocusedState(false);
	}

	onVisibleChanged: 
	{
		updateStateAsDefaultButton();
		updateFocusState();
	}
	onEnabledChanged: 
	{
		updateStateAsDefaultButton();
		updateFocusState();
	}
	onSetAsDefaultButtonChanged: updateStateAsDefaultButton();
	onActiveFocusChanged: updateFocusState()
	Component.onCompleted: 
	{
		if (setAsDefaultButton)
			updateStateAsDefaultButton();
		updateFocusState()
    }
}
