import QtQuick 1.1
import "../Common.js" as Common
import "../Stat.js" as Stat

FocusScope
{
    id: widget
	objectName: "listCombo"

    property variant target
    property string property
	property variant localizer
	property variant keyList
    property alias textfont: linkValue.textfont
    property alias textcolor: linkValue.textcolor

    width: linkValue.width
    height: linkValue.height

    property int tabOrder: 1

    // internal use only!
    signal pressed(int index)
    property variant menu

    onKeyListChanged: updateMenu()
	onLocalizerChanged: updateMenu()

    function updateMenu()
    {
        if (menu)
            menu.destroy()
        var menuItemText = buildMenuItemText();
        if (menuItemText)
            menu = Qt.createQmlObject(menuItemText, widget, "dynamicMenu")
    }

    function isListEmpty()
    {
        if (!keyList)
            return true;
        for (var i in keyList)
            return false;
        return true;
    }

    function buildMenuItemText()
    {
        if (isListEmpty())
            return;
        var menuText = 'import QtWidgetProxies 1.0; PopupMenu{';
        menuText += ' styleSheet: "border-width:1px; border-style: solid; border-color: gray;';
        menuText += ' background-color: rgb(255, 255, 255);selection-background-color: rgb(26, 152, 133); font:10pt FranklinGothicMediCondTT;";'
        menuText += ' items: ['
        var elementIndex = 0;
        for (var i in keyList)
        {
            if(elementIndex > 0)
                menuText +=',';
            menuText += 'PopupMenuAction{text : "';
            menuText += localizer == undefined ? keyList[i] : localizer.Localize(keyList[i]);
            menuText += '"; onTriggered:widget.pressed(';
            menuText += elementIndex;
            menuText += ') }';
            ++elementIndex;
        }
        menuText += ']}';
        return menuText;
    }

    function getNearRect(item)
    {
        return Qt.rect(item.x, item.y, item.width, item.height)
    }

    Button
    {
        id:linkValue
		objectName: "popupMenuOpener"
        setFocusOnPressed: true
        focus: true
        tabOrder: widget.tabOrder ? 1 : 0
        borderLeft: 2
        buttonHeight: 21
        borderRight: 20
        rightMargin: 15
        textLeft: true
        horizontalMargin: 7
        textVerticalOffset: 0
        textcolor: "black"

        text: target && !isListEmpty() && property ?
                  widget.localizer == undefined ? keyList[target[property]] : widget.localizer.Localize(keyList[target[property]]) : ""
        backgroundImage: "../images/widgets/combobox_normal.png"
        hoverImage: "../images/widgets/combobox_hover.png"
        pressedImage: "../images/widgets/combobox_pressed.png"
        disabledImage: "../images/widgets/combobox_disabled.png"
        onClicked: widget.menu.ShowNearItem(getNearRect(linkValue));
        mirror: Window.Mirror

        focusRectEnabled: false
        FocusImage
        {
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            tileHorizontally: true
            widthClipperSize: -20
            border {
                left: 4
                right: 4
            }
            source: "../images/focuses/focus_footer_secondary.png"
        }
    }

    onPressed:
	{
		target[property] = index;

		var path = Common.buildDelegatelessPath(widget)  + ".popupMenu." + keyList[target[property]];
        Stat.onButtonClick(path);
	}
}

