import QtQuick 1.1

Item
{
    id: tabBar
    objectName: "TabBar"

    property Item tabFrame

    property int tabLeftMargin
    property int tabRightMargin

    property int tabTextPointSize
    property string tabTextFamily
    property bool tabTextBold

    visible: tabFrame ? tabFrame.tabsVisible : true

    height: childrenRect.height

    Keys.onRightPressed: {
        if (tabFrame && tabFrame.current < tabFrame.count - 1)
            tabFrame.current = tabFrame.current + 1
    }

    Keys.onLeftPressed: {
        if (tabFrame && tabFrame.current > 0)
            tabFrame.current = tabFrame.current - 1
    }

    onTabFrameChanged:
    {
        parent = tabFrame
    }

    function tab(index)
    {
        for (var i = 0; i < tabRow.children.length; ++i)
        {
            if (tabRow.children[i].tabindex === index)
            {
                return tabRow.children[i]
            }
        }
        return null;
    }

    Rectangle
    {
        color: "#bebebe"
        height: 1
        anchors.bottom: tabRow.bottom
        anchors.left: parent.left
        anchors.right: parent.right
    }

    Row
    {
        id: tabRow
        height: 31
        anchors.left: parent.left
        anchors.leftMargin: 10

        Repeater
        {
            id: repeater
            focus: true
            model: tabFrame.tabs.length ? tabFrame.tabs : null

            delegate: Item
            {
                id: tab
                objectName: "tab"

                focus: true
                property int tabIndex: index
                property bool selected : tabFrame.current === index

                z: selected ? 1 : -1

                anchors.bottom: parent.bottom
                width: tabBarItem.width - (tab.selected ? 6 : 0)
                height: tabBarItem.height

                BorderImage
                {
                    id: tabBarItem
                    objectName: "tabBarItem"

                    property bool first: index === 0

                    width: tabTextItem.width + tabBar.tabLeftMargin + tabBar.tabRightMargin + (tab.selected ? 6 : 0)
                    anchors.left: parent.left
                    anchors.leftMargin: (tab.selected ? -3 : 0)
                    anchors.top: parent.top
                    anchors.topMargin: tab.selected ? 0 : 2
                    height: sourceSize.height
                    focus: tab.selected
                    border {
                        left: 4
                        right: 4
                    }

                    source: tab.selected ? '../images/widgets/tab_selected.png' : (mouseArea.containsMouse ? '../images/widgets/tab_hover.png' : '../images/widgets/tab_normal.png')

                    Text
                    {
                        id: tabTextItem
                        visible: true
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: tab.selected ? 0 : -2
                        text: tabFrame.tabs[index].title
                        font.family: tabBar.tabTextFamily
                        font.pointSize: tabBar.tabTextPointSize
                        font.bold: tabBar.tabTextBold
                    }

                    MouseArea
                    {
                        id: mouseArea
                        anchors.fill: parent
                        hoverEnabled: true
                        Clickable {}
                        onPressed:
                        {
                            tabFrame.previous = tabFrame.current
                            tabFrame.current = index
                        }
                    }
                }

                Rectangle
                {
                    color: "#fea4a6"
                    height: 1
                    anchors.bottom: parent.bottom
                    visible: !tab.selected
                    anchors.left: parent.left
                    anchors.right: parent.right
                }

            }
        }
    }


}
