import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/EnumHelper.js" as EnumHelper
import "../common/fonts" as Fonts
import "../main_window" as MainFrame
import "../common/HelpMapper.js" as HelpMapper

MainFrame.InnerContent
{
	id:				onlineServices
    objectName:		"onlineServices"
    anchors.fill:	parent
    
    Localizer { id:tr; scope:"Online" }

    property variant context:		MainWindow.online
    caption:						tr.Localize("CloudProtection")
    property string onlineStateInt:	context.OnlineState
    property string ksnState:		""
    property variant fontStyles: Fonts.Online{}

    property int helpId: HelpMapper.KsnOnlineServicesHelpId

	captionArea: Component
	{
		Item 
		{
			Widgets.CaptionButton
			{
				objectName:	"ButtonToAboutCloudProtection"
                minWidth: 0
				function showPanel(panel)
				{
					innersView.show("panelAboutCloudProtection");
				}
				text: tr.Localize("ReadMore")
				onClicked: {  showPanel("panelKsnInfo"); }
            }
		}
	}
	
	onOnlineStateIntChanged:
    {
        ksnState = EnumHelper.getKey(context, "OnlineState")
    }

    function getConnectedButtonImage(state)
    {
		return state == "Online" ? "../common/images/ksn/connected.png" : "../common/images/ksn/disconnected.png"
    }
	
    viewArea: Component
    {
        Rectangle
        {
			property int globalRadius: 12
            radius: globalRadius
			objectName:	"viewArea"	
			anchors.fill: parent
			

            Component.onCompleted:
            {
                context.SendRequestCloudInfo();
            }            

            BorderImage
            {
                id: background
                anchors.fill: parent
                horizontalTileMode: BorderImage.Repeat
                verticalTileMode: BorderImage.Repeat
                source: "../common/images/main_window/background.png"
            }

            Column
            {
                id: connectingPage
                visible: ksnState == "Connecting"
                anchors.centerIn: parent
                anchors.verticalCenterOffset: 10
                Widgets.Loading48
                {
                    id: hourGrass
                    anchors.horizontalCenter: parent.horizontalCenter
                }
                Item {width: parent.width; height: 18 }
                Text
                {
                    text: tr.Localize("WaitPlease")
                    font: fontStyles.standardBoldSubHeadingFont
                    anchors.horizontalCenter: parent.horizontalCenter
                }
                Item {width: parent.width; height: 2 }
                Text
                {
                    text: tr.Localize("RequestProcessing")
                    font: fontStyles.normal
                    anchors.horizontalCenter: parent.horizontalCenter
                }
            }

            Item
            {
				anchors.fill        : parent
				objectName:	"NotConnectedPage"	
				visible: ksnState != "Connecting"
								
				Item
				{
					id:		bannerPane
                    width:	217
					anchors.left: parent.left
					height: parent.height
					
					Image
					{
						id:		banner
						y:		20
						anchors.horizontalCenter: parent.horizontalCenter
						source: "../common/images/ksn/ksn_logo.png"
					}
					
					Image
					{
						id:		onlineState
						anchors.top:       banner.bottom
                        anchors.topMargin: 22
						anchors.horizontalCenter: parent.horizontalCenter
						source: getConnectedButtonImage(ksnState)
					}
					
					Text
					{
						text: tr.Localize(ksnState == "Online" ? "Connected" : "Disconnected")
						color: "white"
						anchors.horizontalCenter: onlineState.horizontalCenter
						anchors.verticalCenter: onlineState.verticalCenter
						font: fontStyles.boldNormal
					}
					
					Image
					{
						id:		logo
						anchors.bottom:           parent.bottom
						anchors.bottomMargin:     20
						anchors.horizontalCenter: parent.horizontalCenter
						source: "../common/images/ksn/kas_trusted.png"
					}
				}
				
				Item
				{
					id: ksnInfoArea
					objectName:	"ksnInfoArea"	
					anchors.left  : bannerPane.right
					anchors.right : parent.right
					anchors.top   : parent.top
                    anchors.bottom: parent.bottom
				
                    Rectangle
					{
						id:		ksnInfoAreaBg
                        anchors.fill: parent
                        color: "white"
					}

                    Rectangle
                    {
                        id: ksnInfoAreaBorder

                        anchors.left: ksnInfoAreaBg.left
                        height: parent.height
                        width: 1
                        color: "#E7E7E7"
                    }
					
					Column
					{
						objectName:	"ksnInfoAreaDetail"
						anchors.fill: parent
						anchors.topMargin  : 20						
						anchors.leftMargin : 25
						anchors.rightMargin: 25
                        spacing: 16

						OnlineServiceContent
						{
							id: ksnOverview
							objectName:	"ksnOverview"	
							width: parent.width
							height: childrenRect.height
							infoItems: ListModel
							{
								ListElement{level:"gray"; body:"AboutWorldNetwork"}
								ListElement{level:"gray"; body:"AboutReaction"}
								ListElement{level:"gray"; body:"AboutWebInfo"}
							}
						}
						
						OnlineServiceStatus
						{
							objectName:	"onlineServiceStatus"	
							width: parent.width
							height: childrenRect.height
						}
					}
				}
			}
		}
	}
}
