import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/border" as Border
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/Margins.js" as Margins
import "../common/EnumHelper.js" as EnumHelper
import "../common/HelpMapper.js" as HelpMapper

Border.BorderedContent
{
    content: virtualKeyboardUrlInclusiveDialog

    property variant context: UrlMasksDialogViewModel
    property variant commonFontStyles: Fonts.Common{}

    Widgets.SecondaryWindow
    {
        id: virtualKeyboardUrlInclusiveDialog
        objectName: "VirtualKeyboardRulesWindow"
        width: 400
        height: 300
        Localizer { id: tr; scope: "VirtualKeyboardInclusiveUrlMaskDialog" }
        caption: tr.Localize("Caption" + EnumHelper.getKey(context, "editMode"));

        workArea: FocusScope
        {
            objectName: "WorkArea"

            Column
            {
                id: dialogColumn

                anchors.fill:parent

                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: Margins.verticalCommonTextToWidget

                spacing: 10

                Text
                {
                    id: urlLabel

                    anchors.left: parent.left

                    font: commonFontStyles.standardCommonTextFont
                    horizontalAlignment: Text.AlignLeft

                    text: tr.Localize("UrlInclusiveLabel");
                }

                Widgets.EditBox
                {
                    focus: true

                    anchors.left: parent.left
                    anchors.right: parent.right

                    target: context
                    property: "urlMask"

                    tabOrder: 0
                }

                Item
                {
                    id: urlInputErrorBlock

                    visible: !context.urlCorrect

                    anchors.left: parent.left;
                    anchors.right: parent.right;
                    anchors.leftMargin: 10

                    height: textForInputError.height + 10

                    Image
                    {
                        id: warningIcon
                        anchors.left: parent.left;
                        anchors.verticalCenter: parent.verticalCenter
                        source: "../common/images/ico_warning_16.png"
                    }
                    Text
                    {
                        id: textForInputError
                        objectName: "textForInputError"
                        anchors.left: warningIcon.right; anchors.leftMargin: 5
                        anchors.right: parent.right;

                        anchors.verticalCenter: parent.verticalCenter

                        verticalAlignment:	Text.AlignVCenter

                        text:	tr.Localize("UrlInputError")
                        font:	commonFontStyles.standardCommonTextFont
                        wrapMode: Text.Wrap
                        horizontalAlignment: Text.AlignLeft
                    }
                }

                Widgets.EnumRadioGroup
                {
                    anchors.left: parent.left
                    anchors.leftMargin: 5

                    horizontalMargin: 7

                    target: context
                    property: "actionType"
                    localizer: tr
                    spacing: 6
                }
            }
        }

        buttonsArea: FocusScope
        {
            id: bottomRow
            anchors.fill: parent
            objectName: "bottom"
            property int tabOrder: 2
            property int helpId: HelpMapper.VirtualKeyboardIncludeHelpId


            Widgets.HelpButton
            {
                anchors
                {
                    verticalCenter: parent.verticalCenter
                    left: parent.left
                    leftMargin: 12
                }

                objectName: "help"
                text: tr.Localize("Help")
                onClicked: Help.Show(bottomRow.helpId)
            }

            Widgets.GrayButton
            {
                id: okButton

                minWidth: cancelButton.width
                enabled: context.urlCorrect

                anchors
                {
                    verticalCenter: parent.verticalCenter
                    right: cancelButton.left
                    rightMargin: Margins.horizontalBetweenButtons
                }

                objectName: "OkButton"
                text: tr.Localize("ConfirmButton")
                onClicked:
                {
                    context.dialogResult = 0;
                    Window.Close();
                }
            }

            Widgets.GrayButton
            {
                id: cancelButton

                anchors
                {
                    verticalCenter: parent.verticalCenter
                    right: parent.right
                }

                objectName: "CancelButton"
                text: tr.Localize("CancelButton")
                onClicked:
                {
                    context.dialogResult = 1;
                    Window.Close()
                }
            }
        }

        Widgets.DPIScaler {
            id: dpiScaler
            changeHeight: true
        }
    }
}
