import QtQuick 1.1
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets

Item
{
	property variant commonFontStyles: Fonts.Common{}
	property string groupName
	property variant model
	property string currentFeatureName: settingsList.count > 0 ? settingsList.currentItem.name : ""
	id: featureList
	objectName: "FeatureList"

	onModelChanged: settingsList.setModel(model)

	function selectPage(name)
	{
		var index = pageIndexFromName(name);
		if (index == -1)
		{
			console.log("page " + name + " not found")
			return
		}
		settingsList.currentIndex = index;
	}

	function pageIndexFromName(name)
	{
		for (var i in model)
		{
			if (model[i] == name)
				return i;
		}
		return -1;
	}

	Text
	{
		id: settingsCaption
		anchors.top: parent.top
        anchors.topMargin: 18
        anchors.left: parent.left
        anchors.leftMargin: 13
		text: groupName != "" ? tr.Localize(groupName) : ""
        font: commonFontStyles.standardSettingsBoldTextFont
	}

	Component
	{
        id: featureDelegate

		Widgets.BaseButton
		{
			property string name: modelData
            objectName: groupName+"."+name
            height: featureText.height + 7
            width: parent ? parent.width : 0
            focusRectEnabled: false
            Widgets.FocusImage
            {
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
                tileHorizontally: true
                widthClipperSize: 4
                border {
                    left: 4
                    right: 4
                }
                source: "../common/images/focuses/focus_header_button.png"
            }

            Widgets.DPIScaler { changeHeight: true }
			Rectangle
			{
                anchors.fill: parent
                color: "#ffb5b7"
				visible: parent.state === "hover" && parent.ListView.view.currentIndex !== index
			}

            Rectangle
            {
                anchors.fill: parent
                color: "#af0006"
                visible: parent.ListView.view.currentIndex === index
            }

			Image
			{
                id: feautureImage
				anchors.verticalCenter: parent.verticalCenter
				anchors.left: parent.left
                anchors.leftMargin: 7
                smooth: true
				source: "../common/images/settings/features/" + name + ".png";

                Widgets.DPIScaler { changeSize: true }
			}

            SettingsStandardText
			{
				id: featureText
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: feautureImage.right
                anchors.leftMargin: 9
                anchors.right: parent.right
                anchors.rightMargin: 4
                text: tr.Localize(name)
                wrapMode: Text.WordWrap
				color: parent.ListView.view.currentIndex === index ? "white" : "black"
			}

            onClicked: ListView.view.currentIndex = index
            Keys.onUpPressed:
            {
                if (ListView.view.currentIndex > 0)
                    ListView.view.currentIndex--;
            }
            Keys.onDownPressed:
            {
                if (ListView.view.currentIndex < (ListView.view.count - 1))
                    ListView.view.currentIndex++;
            }
		}
	}

	ListView
	{
		id: settingsList
		interactive: false
		objectName: "settingsList"
        anchors.left: parent.left
        anchors.leftMargin: 7
        anchors.right: parent.right
        anchors.rightMargin: 8
		anchors.top: settingsCaption.bottom
        anchors.topMargin: 8
		anchors.bottom: parent.bottom
		model: featureList.model
        delegate: featureDelegate
		highlightMoveSpeed: -1

		function modelToIndex() {}
		function setModel(newModel)
		{
			if (model)
				modelToIndex[model] = currentIndex;
			if (!newModel)
				return;
			model = newModel;
			var newIndex = modelToIndex[model];
            currentIndex = newIndex === undefined ? 0 : newIndex;
		}

        Widgets.DPIScaler { changeSize: true }
    }


}
