import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper


Item
{
    id: settingsPage
	objectName: "IntrusionDetector"

    property int helpId: HelpMapper.IntrusionDetectorSettingsHelpId

	property variant context: SettingsHelper.GetPageContext(Settings, "IntrusionDetector")
    property variant fontStyles: Fonts.Common{}

	Localizer { id: tr; scope: "IntrusionDetectorSettings" }

	Column
	{
        objectName: "MainWrapper"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "GeneralIntrusionDetector"
            body: Column
            {
                objectName: "GeneralIntrusionDetectorSection"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    text: tr.Localize("Description_" + ProductTypeHelper.productTypeToString(context))
                    wrapMode: Text.Wrap
                }

                SettingsCommon.CheckBox
                {
                    objectName: "EnableIntrusionDetector"
                    text: tr.Localize("UseIntrusionDetector");
                    isBold: true
                    target: context
                    property: "enableIntrusionDetector"
                    anchors.left: parent.left
                }

                Item
                {
                    enabled: context.enableIntrusionDetector
                    objectName: "Ban"
                    width: parent.width
                    height: Math.max(banText.height, banRow.height)

                    SettingsCommon.CheckBox
                    {
                        id: banText
                        objectName: "BanAttackComputer"

                        height: banRow.height
                        text: tr.Localize("BanAttackComputer");
                        target: context
                        property: "ban"
                        anchors.left: parent.left
                        anchors.verticalCenter: parent.verticalCenter
                    }

                    Row
                    {
                        objectName: "Row"
                        id: banRow
                        height: childrenRect.height
                        anchors.left: banText.right
                        anchors.leftMargin: Margins.settingsBeforeSpinEdit
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: 2
                        enabled: parent.enabled && context.ban
                        spacing: Margins.settingsAfterSpinEdit

                        Widgets.IntSpinEdit
                        {
                            objectName: "SpinEdit"
                            target: context
                            property: "banTimeout"
                            minValue: 1
                            maxValue: 9999
                        }

                        Text
                        {
                            anchors.verticalCenter: parent.verticalCenter
                            text: tr.Localize("Min")
                            color: parent.enabled ? "black" : "grey"
                        }
                    }
                }
            }
        }		
	}
}
