import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/Colors.js" as Colors
import "../../common/widgets" as Widgets
import ".." as SettingsCommon
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Rectangle
{
	id: settingsPage
	objectName: "ParentalControlSettings"

    property int helpId: HelpMapper.ParentalControlSettingsHelpId
	property string helpUrl: "$HelpURLSettingsParCtl"

    anchors.top: parent.top
    anchors.topMargin: 7
    anchors.left: parent.left
    width: parent.width
    anchors.bottom: parent.bottom
	property variant context: SettingsHelper.GetPageContext(Settings, "ParentalControl")
	border.width: 1
	border.color: Colors.grayBorder
	function invertControl(accountId)
	{
		context.InvertControl(accountId);
	}
	function showSettings(accountId)
	{
		context.ShowSettings(accountId);
	}

	Localizer { id: tr; scope:"ParentalControl" }

	BorderImage
	{

        id: toolbarWrapper
		source: "../../common/images/settings/firewall/toolbar.png"
        height: sourceSize.height
        width: parent.width
		Widgets.DPIScaler {changeHeight: true}

        anchors
        {
            left: parent.left
            leftMargin: 1
            top: parent.top
            topMargin: 1
            right: parent.right
        }

        Row
        {
            id: toolbar
            objectName: "Row"
            anchors.left: parent.left
            anchors.leftMargin: 3
            anchors.verticalCenter: parent.verticalCenter

            SettingsCommon.SettingsToolbarButton
            {
                objectName: "Control"
                property bool controlEnabled: list.currentItem.controlEnabled
                iconImage: "../../common/images/settings/parental_control/bullet_" + (controlEnabled ? "off" : "on") + "_10.png"
                text: tr.Localize(controlEnabled ? "TurnOff" : "TurnOn")
                onClicked: invertControl(list.currentItem.accountId);
            }
            SettingsCommon.SettingsToolbarButton
            {
                objectName: "Settings"
                iconImage: "../../common/images/settings/parental_control/settings.png"
                text: tr.Localize("SettingsButtonText")
                onClicked: showSettings(list.currentItem.accountId);
            }
        }
    }

    Rectangle
    {
        id: separator
        anchors.top: toolbarWrapper.bottom
        anchors.left: parent.left
        anchors.leftMargin: 1
        anchors.right: parent.right
        height: 1
        color: Colors.grayBorder
    }

	ListView
	{
		id: list
		anchors
		{
            top: separator.bottom
			left: parent.left
			leftMargin: 1
			right: parent.right
			bottom: parent.bottom
		}
		model: context.accounts
		focus: true
		clip: true
		delegate: Rectangle
		{
			id: rect
			property string accountId: modelData.id
			property bool controlEnabled: modelData.isControlEnabled
			property int tabOrder: 1
            height: 80
			width: parent.width;
            color: ListView.view.currentIndex === index ? "#af0006" : "white"
            function getCurrentTextColor(itemId)
            {
                return ListView.view.currentIndex === index ? "white" : "black"
            }
            function getCurrentOkColor(itemId)
            {
                return ListView.view.currentIndex === index ? "white" : Colors.green
            }
            function getCurrentAlertColor(itemId)
            {
                return ListView.view.currentIndex === index ? "white" : Colors.red
            }
			function showSettings()
			{
				settingsPage.showSettings(accountId);
			}
			Keys.onUpPressed:
			{
				if (ListView.view.currentIndex > 0)
					ListView.view.currentIndex--;
			}
			Keys.onDownPressed:
			{
				if (ListView.view.currentIndex < (ListView.view.count - 1))
					ListView.view.currentIndex++;
			}
			Keys.onSpacePressed: showSettings()
			Image
			{
				id: image
				anchors.verticalCenter: parent.verticalCenter;
				anchors.left: parent.left;
				anchors.leftMargin: y;
				function getAvatarSuffix()
				{
					switch (modelData.iconId)
					{
						case "Mother":
							return "girl_01";
						case "SonMajor":
							return "son";
						case "DotherMajor":
							return "daughter";
						case "SonMinor":
							return "son_jr";
						case "DotherMinor":
							return "daughter_jr";
						case "Father":
						default:
							return "man_01";
					}
				}
				source: "../../common/images/parental_control/avatar_" + getAvatarSuffix() + ".png";
			}

			Column
			{
				anchors
				{
					left: image.right
                    leftMargin: 20
					verticalCenter: parent.verticalCenter
					right: parent.right
					rightMargin: 25
				}

				Widgets.StandardCaptionText
				{
					id: accountName
					elide: Text.ElideRight
					text: modelData.name;
					horizontalAlignment: Text.AlignLeft
                    color: getCurrentTextColor(parent.parent)
				}

				Text
				{
					text: tr.Localize(modelData.isControlEnabled ? "ControlIsTurnedOn" : "ControlIsTurnedOff")
                    color: modelData.isControlEnabled ? getCurrentOkColor(parent.parent) : getCurrentAlertColor(parent.parent)
					font.pointSize: 10
				}
			}

			MouseArea
			{
				anchors.fill: parent
				onClicked: { rect.ListView.view.currentIndex = index; forceActiveFocus() }
				onDoubleClicked: showSettings()
			}
		}
	}

    Widgets.ScrollBar
	{
        height: list.height
		anchors.verticalCenter: list.verticalCenter
        anchors.right: list.right
		target: list
	}

}
