import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/border" as Border
import "../common/fonts" as Fonts
import "../common/Common.js" as Common

Rectangle
{
    property int rowHeight: 30
    property alias model: tableView.model
    property variant commonFontStyles: Fonts.Common{}

    Component
    {
        id: defaultCellComponent

        Item
        {
            width: 100
            height: rowHeight
            property variant file;
            Text
            {
                id: cdText
                property int denominator: Common.getShortFileSizeString(file["fileSize"])

                text: (file["fileSize"] / Math.pow(1024, denominator)).toFixed(2)
                      + " " + Common.getFileSizeSuffix(denominator)
                font: commonFontStyles.standardCommonTextFont
                width: parent.width - 10
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.verticalCenter: parent.verticalCenter
                elide: Window.Mirror ? Text.ElideLeft : Text.ElideRight
            }

            Widgets.DPIScaler {changeHeight: true}
        }
    }

    Component
    {
        id: defaultHeaderComponent

        Item
        {
            width: 100
            height: rowHeight
            property alias text: cdText.text
            Text
            {
                id: cdText
                width: parent.width - 10
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.verticalCenter: parent.verticalCenter
                elide: Window.Mirror ? Text.ElideLeft : Text.ElideRight
            }

            Widgets.DPIScaler {changeHeight: true}
        }
    }

    Component
    {
        id: checkBoxAndTextCellComponent
        Item
        {
            width: 100
            height: rowHeight
            property variant file;

            Widgets.CheckBox
            {
                id: checkBox
                text: file["fileName"]
                textfont: commonFontStyles.standardCommonTextFont

                anchors.verticalCenter: parent.verticalCenter
                anchors.left: parent.left
                anchors.leftMargin: 10
                width: parent.width - 10
                elide: Window.Mirror ? Text.ElideLeft : Text.ElideRight
                target: file
                property: "isChecked";
            }

            Widgets.DPIScaler {changeHeight: true}
        }
    }

    SupportTableView
    {
        id: tableView
        anchors.left: parent.left
        anchors.right: scrollbar.left
        height: parent.height
        headerVisible: true

        Widgets.DPIScaler {changeHeight: true}

        columnResizeIndicatorDelegate:
            Rectangle
            {
                color: "#dadada"
                width: 1
            }
        headerRowDelegate:
            Rectangle
            {
                color: "#fafafa"

                Rectangle
                {
                    anchors.bottom: parent.bottom
                    width: parent.width
                    color: "#dadada"
                    height: 1
                }
            }
        rowDelegate:
            Rectangle
            {
                property int index
                width: tableView.width
                height: rowHeight
                color: index % 2 ? "#fafafa" : "white"
            }
        columns:
        [
            SupportTableColumn
            {
                id: firstColumn
                width: parent.width * 0.7
                minimumWidth: 100
                cellDelegate: checkBoxAndTextCellComponent
                headerDelegate: defaultHeaderComponent
                type: "type"
                title: tr.Localize("File")
            },
            SupportTableColumn
            {
                id: secondColumn
                width: parent.width - firstColumn.width
                minimumWidth: 30
                cellDelegate: defaultCellComponent
                headerDelegate: defaultHeaderComponent
                title: tr.Localize("Size")
            }
        ]
    }

    Widgets.ScrollBar
    {
        id: scrollbar
        target: tableView
        anchors
        {
            right: parent.right;
            top: parent.top;
            bottom: parent.bottom
        }
    }
}
