import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/border" as Border
import "../common/fonts" as Fonts
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/DateTime.js" as DateTime
import "SupportMargins.js" as Margins


Item
{
    objectName: "SupportMain"
    signal monitoring

    property variant context: SupportWindow
    property variant commonFontStyles: Fonts.Common{}
    property variant productType: ProductTypeHelper.productTypeToString(context)
    Localizer { id: tr; scope: "Support" }

    Rectangle
    {
        id: supportInfoRect
        objectName: "SupportInfo"

        anchors.top: parent.top
        anchors.left: parent.left
        width: parent.width

        height: 177
        color: "white"


        Item
        {
            anchors.fill: parent
            Image
            {
                id: supportImage

                source: "../common/images/support/ico_support_big.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: parent.left
                anchors.leftMargin: 22

                Widgets.DPIScaler { changeSize: true }
            }

            Column
            {
                id: supportInfoColumn
                objectName: "SupportInfoColumn"

                anchors.top: supportImage.top
                anchors.topMargin: -3
                anchors.left: supportImage.right
                anchors.bottom: parent.bottom

                anchors.leftMargin: 5
                anchors.rightMargin: 10

                spacing: 12
                property int leftColumnWidth: 145
                property int rightColumnWidth: 265

                Widgets.DPIScaler { id: dpiScaler; changeAll: true; }

                Text
                {
                    anchors.left: parent.left
                    text: tr.Localize("Support_" + productType)
                    font: commonFontStyles.standardSmallCaptionFont
                    horizontalAlignment: Text.AlignLeft

                    Widgets.DPIScaler { changeSize: true }
                }

                Column
                {
                    objectName: "infoRowsWrapper"
                    spacing: 5

                    Row
                    {
                        anchors.left: parent.left
                        height: applicationVersion.height
                        Text
                        {
                            id: applicationVersion
                            anchors.top: parent.top
                            width: supportInfoColumn.leftColumnWidth
                            text: tr.Localize("ApplicationVersion")
                            font: commonFontStyles.standardCommonTextFont
                            horizontalAlignment: Text.AlignLeft

                            Widgets.DPIScaler { changeSize: true }
                        }

						Item
						{
							height: parent.height
							width: supportInfoColumn.rightColumnWidth
	                        Text
	                        {
	                        	id: applicationVersionText
	                            text: context.applicationVersion
	                            font: commonFontStyles.standardCommonTextFont
	                            horizontalAlignment: Text.AlignLeft

	                            Widgets.DPIScaler { changeSize: true }
	                        }
	                        Text
	                        {
	                        	anchors.left: applicationVersionText.right
	                            width: parent.width - applicationVersionText.width
								text: context.applicationHotfix ? (" (" + context.applicationHotfix.split(".").pop() + ")") : ""
	                            elide: Text.ElideLeft
	                            font: commonFontStyles.standardCommonTextFont
	                            horizontalAlignment: Text.AlignLeft

	                            Widgets.DPIScaler { changeSize: true }
	                        }
	                    }
                        Widgets.DPIScaler { changeAll: true; }
                    }

                    Row
                    {
                        anchors.left: parent.left
                        height: dbReleaseDate.height
                        Text
                        {
                            id: dbReleaseDate
                            anchors.top: parent.top
                            width: supportInfoColumn.leftColumnWidth
                            text: tr.Localize("DatabaseReleaseDate")
                            font: commonFontStyles.standardCommonTextFont
                            horizontalAlignment: Text.AlignLeft
							wrapMode: Text.WordWrap

                            Widgets.DPIScaler { changeSize: true }
                        }

                        Text
                        {
                            anchors.top: parent.top
                            width: supportInfoColumn.rightColumnWidth
                            text: tr.LocalizeDateTimeShort(context.databaseReleaseDate)
                            font: commonFontStyles.standardCommonTextFont
                            horizontalAlignment: Text.AlignLeft

                            Widgets.DPIScaler { changeSize: true }
                        }
                        Widgets.DPIScaler { changeAll: true; }
                    }

                    Row
                    {
                        anchors.left: parent.left
                        height: operationSystem.height
                        Text
                        {
                            anchors.top: parent.top
                            width: supportInfoColumn.leftColumnWidth
                            text: tr.Localize("OperationSystem")
                            font: commonFontStyles.standardCommonTextFont
                            horizontalAlignment: Text.AlignLeft

                            Widgets.DPIScaler { changeSize: true }
                        }

                        Text
                        {
                            id: operationSystem
                            anchors.top: parent.top
                            width: supportInfoColumn.rightColumnWidth
                            text: context.operationSystem
                            font: commonFontStyles.standardCommonTextFont
                            horizontalAlignment: Text.AlignLeft
                            wrapMode: Text.WordWrap

                            Widgets.DPIScaler { changeSize: true }
                        }
                        Widgets.DPIScaler { changeAll: true; }
                    }

                    Row
                    {
                        objectName: "LicenseRow"
                        anchors.left: parent.left
                        height: licenseText.height
                        Text
                        {
                            id: licenseText
                            anchors.top: parent.top
                            width: supportInfoColumn.leftColumnWidth
                            text: context.hasLicense && context.isLicenseSubcription ? tr.Localize("Subscription") : tr.Localize("License")
                            horizontalAlignment: Text.AlignLeft
                            font: commonFontStyles.standardCommonTextFont

                            Widgets.DPIScaler { changeSize: true }
                        }

                        Text
                        {
                            text: tr.Localize("hasNoLicense")
                            font: commonFontStyles.standardCommonTextFont
                            horizontalAlignment: Text.AlignLeft
                            opacity: context.hasLicense ? 0 : 1

                            Widgets.DPIScaler { changeSize: true }
                        }

                        Widgets.Hyperlink
                        {
                            objectName: "ActiveLicenseLink"
                            width: supportInfoColumn.rightColumnWidth
                            text: context.activeLicenseKey
                            horizontalAlignment: Text.AlignLeft
                            color: "#5495DF"
                            opacity: context.hasLicense ? 1 : 0
                            onClicked:
                            {
                                context.OpenLicenseInfo()
                            }

                            Widgets.DPIScaler { changeSize: true }
                        }
                        Widgets.DPIScaler { changeAll: true; }
                    }
                }

            }
            Widgets.DPIScaler { changeHeight: true }
        }

        Widgets.DPIScaler { changeHeight: true }
    }

    Rectangle
    {
        id: supportBorder
        anchors
        {
            top: supportInfoRect.bottom
            left: parent.left
            right: parent.right
        }
        height: 1
        color: "#CCCCCC"
    }

    Rectangle
    {
        id: supportActions
        objectName: "SupportMainButtons"
        Component.onCompleted:
		{
			faqButton.width = recommendationsButton.width = Math.max(faqButton.width, recommendationsButton.width)
			forumButton.width = monitoringButton.width = myAccountButton.width = Math.max(forumButton.width, monitoringButton.width, myAccountButton.width)
		}

        anchors.top: supportBorder.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom

        color: "white"

        Widgets.DPIScaler { changeHeight: true }

        Column
        {
            objectName: "SupportMainFirstButtons"
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top

            anchors.leftMargin: Margins.leftMargin
            anchors.topMargin: 30
            anchors.rightMargin: 23

            spacing: 20

            Widgets.DPIScaler { changeSize: true }

            Widgets.GrayButton
            {
                id: faqButton
                objectName: "FAQButton"
                anchors.left: parent.left

                setAsDefaultButton: true
                text: tr.Localize("FAQ")
                onClicked:
                {
                    Window.OpenTemplateURL("$OneClickSupportLink")
                }

                Widgets.DPIScaler { changeSize: true }
            }

            Widgets.GrayButton
            {
                id: recommendationsButton
                objectName: "RecommendationsButton"
                anchors.left: parent.left

                text: tr.Localize("Recommendations")
                onClicked:
                {
                    Window.OpenTemplateURL("$KnowledgeBaseLink")
                }

                Widgets.DPIScaler { changeSize: true }
            }

            Item
            {
                height: 10
            }

            Item
            {
                id: forumRow
                objectName: "ForumButtonRow"
				height: Math.max(forumComment.y + forumComment.height, forumButton.height)
                anchors.left: parent.left
                anchors.right: parent.right

                Widgets.GrayButton
                {
                    id: forumButton
                    objectName: "ForumButton"
                    text: tr.Localize("Forum")
                    anchors.left: parent.left
                    anchors.top: parent.top

                    onClicked:
                    {
                        Window.OpenTemplateURL("$ForumDefURL")
                    }

                    Widgets.DPIScaler { changeSize: true }
                }

                Rectangle
                {
                    id: forumSeparator

                    anchors.verticalCenter: forumButton.verticalCenter
                    anchors.left: forumButton.right
                    anchors.leftMargin: 7

                    height: 1
                    width: 7

                    color: "black"
                }

                Text
                {
                    id: forumComment

                    anchors.top: parent.top
                    anchors.topMargin: forumButton.height / 4
                    anchors.left: forumSeparator.right
                    anchors.leftMargin: 7
                    anchors.right: parent.right
                    anchors.rightMargin: 10

                    font: commonFontStyles.standardCommonTextFont
                    text: tr.Localize("ForumComment")
                    horizontalAlignment: Text.AlignLeft

                    wrapMode: Text.WordWrap
                }
            }

            Item
            {
                objectName: "MonitoringButtonRow"
                height: Math.max(monitoringText.y + monitoringText.height, monitoringButton.height)
                anchors.left: parent.left
                anchors.right: parent.right

                Widgets.GrayButton
                {
                    id: monitoringButton
                    objectName: "MonitoringButton"
                    text: tr.Localize("Monitoring")
                    anchors.left: parent.left
                    anchors.top: parent.top

                    onClicked: supportMain.monitoring()

                    Widgets.DPIScaler { changeSize: true }
                }

                Rectangle
                {
                    id: monitoringSeparator

                    anchors.verticalCenter: monitoringButton.verticalCenter
                    anchors.left: monitoringButton.right
                    anchors.leftMargin: 7

                    height: 1
                    width: 7
                    color: "black"
                }

                Text
                {
                    id: monitoringText

                    anchors.left: monitoringSeparator.right
                    anchors.leftMargin: 7
                    anchors.top: parent.top
                    anchors.topMargin: monitoringButton.height/4
                    anchors.right: parent.right
                    anchors.rightMargin: 10

                    font: commonFontStyles.standardCommonTextFont
                    text: tr.Localize("MonitoringComment")
                    wrapMode: Text.WordWrap
                    horizontalAlignment: Text.AlignLeft
                }
            }
			
            Item
            {
                objectName: "myAccountButtonRow"
                height: Math.max(myAccountText.y + myAccountText.height, myAccountButton.height)
                anchors.left: parent.left
                anchors.right: parent.right

                Widgets.GrayButton
                {
                    id: myAccountButton
                    objectName: "myAccountButton"
                    text: tr.Localize("myAccount")
					anchors.left: parent.left
                    anchors.top: parent.top
                    Widgets.DPIScaler { changeSize: true }


                    onClicked: Window.OpenTemplateURL("$MyAccountLink")

                    Widgets.DPIScaler { changeSize: true }
                }
				
				Rectangle
                {
                    id: myAccountSeparator

                    anchors.verticalCenter: myAccountButton.verticalCenter
                    anchors.left: myAccountButton.right
                    anchors.leftMargin: 7

                    height: 1
                    width: 7
                    color: "black"
                }
				
				Text
                {
                    id: myAccountText

                    anchors.left: myAccountSeparator.right
                    anchors.leftMargin: 7
                    anchors.top: parent.top
                    anchors.topMargin: myAccountButton.height/4
                    anchors.right: parent.right
                    anchors.rightMargin: 10

                    font: commonFontStyles.standardCommonTextFont
                    text: tr.Localize("myAccountComment")
                    wrapMode: Text.WordWrap
                    horizontalAlignment: Text.AlignLeft
                }
            }
        }
    }
    Widgets.DPIScaler { changeHeight: true }
}


