import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/border" as Border
import "../common/fonts" as Fonts
import "../common/EnumHelper.js" as EnumHelper
import "../common/Common.js" as Common
import "../common/HelpMapper.js" as HelpMapper

Border.BorderedContent
{
    content: suportSendDumpsDialog

    property variant context: SupportSendReportWindow
    property variant commonFontStyles: Fonts.Common{}
    property int helpId: HelpMapper.SendDumpsHelpId

    Widgets.SecondaryWindow
    {
        id: suportSendDumpsDialog

        width: 550
        height: 490

        Localizer { id: tr; scope: "Support" }
        caption: tr.Localize("Caption");

        workArea: FocusScope
        {
            id: mainArea;
            objectName: "WorkArea"

            property bool sendState: context.sendTroublesState ? EnumHelper.getKey(context, "sendTroublesState") !== "SendStateDone"
                                                                            && EnumHelper.getKey(context, "sendTroublesState") !== "SendStateError"
                                                                          : EnumHelper.getKey(context, "sendTroublesState") !== "SendStateDone"
                                                                            && EnumHelper.getKey(context, "sendTroublesState") !== "SendStateError"
            property bool sendFlag: false

            onSendStateChanged:
            {
                if (sendFlag && EnumHelper.getKey(context, "sendTroublesState") === "SendStateDone")
                    Window.Close()
            }

            Widgets.DPIScaler { changeHeight: true }

            Rectangle
            {
                objectName: "SendReportColumnWrapper"
                anchors.fill: parent
                color: "white"

                Item
                {
                    id: informationColumn
                    anchors.fill: parent
                    anchors.leftMargin: 20
                    anchors.rightMargin: 35
                    anchors.topMargin: 35
                    anchors.bottomMargin: 15

                    property int hideTime: 600

                    Widgets.DPIScaler { changeHeight: true }


                    Item
                    {
                        id: sendInfo
                        anchors.fill: parent

                        Image
                        {
                            id: alertImage

                            anchors.left: parent.left

                            source: "../common/images/ico_warning_48.png"

                            Widgets.DPIScaler { changeSize: true }
                        }

                        Column
                        {
                            anchors.left: alertImage.right
                            anchors.leftMargin: 15
                            anchors.right: parent.right
                            spacing: 10

                            Text
                            {
                                id: warningText

                                width: parent.width
                                font: commonFontStyles.standardCommonTextFontBold
                                lineHeight: 1.2
                                wrapMode: Text.WordWrap
                                horizontalAlignment: Text.AlignLeft
                                text: tr.Localize("SendDumpsWarningText")
                            }

                            Column
                            {
                                width: parent.width
                                spacing: 20

                                Text
                                {
                                    id: foundationText

                                    width: parent.width
                                    font: commonFontStyles.standardCommonTextFont
                                    wrapMode: Text.WordWrap
                                    horizontalAlignment: Text.AlignLeft
                                    text: tr.Localize("SendDumpsFoundation")
                                }

                                Column
                                {

                                    width: parent.width
                                    spacing: 12

                                    Text
                                    {
                                        id: dataDescriptionText

                                        font: commonFontStyles.standardCommonTextFont
                                        wrapMode: Text.WordWrap
                                        horizontalAlignment: Text.AlignLeft
                                        text: tr.Localize("SendDumpsDataDescription")
                                    }

                                    Widgets.CheckBox
                                    {
                                        id: systemInfoCheckBox

                                        text: tr.Localize("SystemInfo")
                                        target: context
                                        property: "isSystemInfoToSend"
                                        textfont: commonFontStyles.standardCommonTextFont
                                        enabled: !sendState
                                    }

                                    Row
                                    {
                                        id: analysisDataRow
                                        width: parent.width
                                        spacing: -5

                                        Widgets.CheckBox
                                        {
                                            id: gatheredDataCheckBox
                                            text: tr.Localize("GatheredData")
                                            enabled: !sendState

                                            textfont: commonFontStyles.standardCommonTextFont
                                            target: context
                                            property: "isAnalysisDataToSend"
                                        }

                                        Widgets.Hyperlink
                                        {
                                            property int denominator: Common.getShortFileSizeString(context.filesToSendSize);
                                            enabled: context.isAnalysisDataToSend && !sendState
                                            text: "(" + tr.Localize("GatheredDataList") + " - " + (context.filesToSendSize / Math.pow(1024, denominator)).toFixed(2)
                                                  + " " + Common.getFileSizeSuffix(denominator) + ")"
                                            anchors.verticalCenter: gatheredDataCheckBox.verticalCenter

                                            color: context.isAnalysisDataToSend ? "#5495df" : "grey"
                                            onClicked:
                                            {
                                                informationColumn.visible = false
                                                filesColumn.visible = true
                                            }
                                        }
                                    }
                                }


                                Column
                                {
                                    width: parent.width
                                    spacing: 10

                                    Text
                                    {
                                        id: sendCommentText

                                        text: tr.Localize("SendComment")

                                        width: parent.width
                                        font: commonFontStyles.standardCommonTextFont
                                        wrapMode: Text.WordWrap
                                        horizontalAlignment: Text.AlignLeft

                                        Widgets.DPIScaler { changeSize: true }

                                        Widgets.ClickableForLinksInText
                                        {
                                            onLinkActivated: context.ShowDataAgreement()
                                        }
                                    }

                                    Widgets.GrayButton
                                    {
                                        id: sendReportButton
                                        text: tr.Localize("Send")

                                        horizontalMargin: 15
                                        enabled: (context.isAnalysisDataToSend || context.isSystemInfoToSend)
                                                 && !sendState

                                        onClicked:
                                        {
                                            context.SendFiles()
                                            sendFlag = true;
                                        }

                                        Widgets.DPIScaler { changeHeight: true }
                                    }
                                }

                            }

                        }

                        Behavior on opacity
                        {
                            NumberAnimation
                            {
                                duration: informationColumn.hideTime;
                                easing.type: Easing.InOutQuad
                            }
                        }
                    }

                    Item
                    {
                        id: statusIndicator

                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: -30
                        anchors.horizontalCenter: parent.horizontalCenter
                        width: parent.width

                        opacity: sendState ? 1 : 0

                        Widgets.Loading48
                        {
                            id: loadingProgress
                            anchors.horizontalCenter: parent.horizontalCenter
                        }

                        Row
                        {
                            anchors.top: loadingProgress.bottom
                            anchors.topMargin: 10
                            anchors.horizontalCenter: parent.horizontalCenter

                            Text
                            {
                                id: statusMessage
                                text: context.sendTroublesState ? tr.Localize(EnumHelper.getKey(context, "sendTroublesState"))
                                                                           : tr.Localize(EnumHelper.getKey(context, "sendTroublesState"));
                                font: commonFontStyles.standardCommonTextFont
                                horizontalAlignment: Text.AlignLeft
                            }

                            Text
                            {
                                id: progressText
                                text: context.currentProgress + "%";
                                font: commonFontStyles.standardCommonTextFont
                                horizontalAlignment: Text.AlignLeft
                            }
                        }

                        Widgets.DPIScaler { changeHeight: true }

                        Behavior on opacity
                        {
                            SequentialAnimation
                            {
                                NumberAnimation
                                {
                                    duration: informationColumn.hideTime;
                                    easing.type: Easing.InOutQuad
                                }
                            }
                        }
                    }


                    Item
                    {
                        id: resultIndicator

                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: -30
                        anchors.horizontalCenter: parent.horizontalCenter

                        opacity: informationColumn.state === "sendState" && !sendState ? 1 : 0

                        Image
                        {
                            id: sign
                            anchors.horizontalCenter: parent.horizontalCenter

                            source: EnumHelper.getKey(context, "sendTroublesState") === "SendStateDone" ? "../common/images/ico_info_48.png"
                                        :   (EnumHelper.getKey(context, "errorCode") === "Canceled" ? "../common/images/ico_warning_48.png"
                                                                                                    : "../common/images/ico_danger_48.png")

                        }

                        Text
                        {
                            id: resultMessage

                            anchors.top: sign.bottom
                            anchors.topMargin: 10
                            anchors.horizontalCenter: parent.horizontalCenter

                            text: EnumHelper.getKey(context, "sendTroublesState") === "SendStateDone" ? tr.Localize(EnumHelper.getKey(context, "sendTroublesState"))
                                          : (context.errorCode ? tr.Localize(EnumHelper.getKey(context, "errorCode"))
                                                                       : tr.Localize(EnumHelper.getKey(context, "errorCode")));
                            font: commonFontStyles.standardCommonTextFont
                            horizontalAlignment: Text.AlignLeft
                        }

                        Timer
                        {
                            running: resultIndicator.opacity == 1
                            interval: 2000

                            onTriggered:
                            {
                                informationColumn.state = "normalState";
                            }
                        }

                        Behavior on opacity
                        {
                            NumberAnimation
                            {
                                duration: informationColumn.hideTime;
                                easing.type: Easing.InOutQuad
                            }
                        }
                    }

                    states:
                    [
                        State
                        {
                            name: "sendState"
                            when: sendState || sendFlag
                            extend: "normalState"
                            PropertyChanges {target: sendInfo; opacity: 0}
                        },
                        State
                        {
                            name: "normalState"
                            when: true === true
                        }
                    ]
                }

                Column
                {
                    id: filesColumn
                    anchors.fill: parent
                    visible: false

                    SupportPanel
                    {
                        id: supportReportFilesListPanel
                        objectName: "sendDumpsPanel"
                        canHome: false;
                        caption: tr.Localize("GatheredDataTitle")
                        onBack:
                        {
                            filesColumn.visible = false
                            informationColumn.visible = true
                        }
                    }

                    SupportFileList
                    {
                        id: fileList
                        objectName: "SupportFilesList"
                        anchors.left: parent.left
                        anchors.right: parent.right
                        height: parent.height - supportReportFilesListPanel.height

                        model: context.fileList
                    }
                }

                SequentialAnimation
                {
                    id: animation
                    property alias oldPanel: oldPanelAnimation.target
                    property alias newPanel: newPanelAnimation.target
                    property bool isBackDirection: false
                    property int velocity: 1200

                    function show(newPanel, oldPanel, back)
                    {
                        isBackDirection = back
                        animation.oldPanel = newPanel
                        animation.newPanel = oldPanel
                        animation.running = true
                    }

                    ScriptAction
                    {
                        script:
                        {
                            animation.newPanel.x = (Window.Mirror ? -1 : 1) * (animation.isBackDirection ? -1 : 1) * mainArea.width
                            animation.newPanel.visible = true
                        }
                    }

                    ParallelAnimation
                    {
                        SmoothedAnimation
                        {
                            id: oldPanelAnimation
                            property: "x";
                            to: (Window.Mirror ? 1 : -1) * (animation.isBackDirection ? -1 : 1) * (target ? target.width : 0)
                            velocity: animation.velocity
                        }
                        SmoothedAnimation
                        {
                            id: newPanelAnimation
                            property: "x";
                            to: 0;
                            velocity: animation.velocity
                        }
                    }
                    ScriptAction
                    {
                        script:
                        {
                            animation.oldPanel.visible = false
                        }
                    }
                }
            }
        }

        buttonsArea: FocusScope
        {
            id: bottomRow
            anchors.fill: parent
            objectName: "bottom"
            property int tabOrder: 2

            Widgets.HelpButton
            {
                anchors
                {
                    verticalCenter: parent.verticalCenter
                    left: parent.left
                    leftMargin: 12
                }

                objectName: "help"
                text: tr.Localize("Help")
                onClicked: Help.Show(helpId)
            }



            Widgets.GrayButton
            {
                id: closeButton

                anchors
                {
                    verticalCenter: parent.verticalCenter
                    right: parent.right
                }

                objectName: "CloseButton"
                text: tr.Localize("CloseButton")
                onClicked:
                {
                    context.MarkShown();
                    Window.Close()
                }
            }
        }

        onClose:
        {
            context.MarkShown();
        }

        Widgets.DPIScaler {
            id: dpiScaler
            changeHeight: true
        }
    }
}
