import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../../common/widgets" as Widgets
import "../../../common/fonts" as Fonts
import "../../../common/HelpMapper.js" as HelpMapper

Item
{
    id: greetings
    objectName: "srcSelectionPage"

    anchors.fill: parent

    property variant context: RescueDiskWizard.GetPageContext()
    property variant commonFontStyles: Fonts.Common{}
    property string textMarker: rescueDiskMain.getMarker()

    function getHelpId()
    {
        return HelpMapper.RescueDiskWizardIntroHelp;
    }

    Column
    {
        anchors.left: parent.left
        anchors.top: parent.top
        anchors.right: parent.right
        anchors.leftMargin: 40
        anchors.rightMargin: 40
        anchors.topMargin: 40
        spacing: 20
        width: parent.width

        Text
        {
            width: parent.width
            font: commonFontStyles.standardSmallCaptionFont
            wrapMode: Text.WordWrap
            text: tr.Localize("SelectionTitle_" + textMarker);
        }

        Rectangle { color: "lightgray"; width: parent.width; height: 1 }

        Text
        {
            width: parent.width
            wrapMode: Text.WordWrap
            text: tr.Localize("SelectionDescription_" + textMarker);
        }

        Text
        {
            text: tr.Localize("SrcSelectionPageRadioText");
            visible: context.isImageSelection
        }

        Widgets.EnumRadioGroup
        {
            id: imageSrcSelection
            horizontalMargin: 7

            target: context
            property: "imageOperation"
            localizer: tr
            spacing: 6
            visible: context.isImageSelection
        }

        Widgets.EnumRadioGroup
        {
            id: outputDevSelection
            horizontalMargin: 7

            target: context
            property: "outputDevice"
            localizer: tr
            spacing: 6
            visible: context.isOutputSelection
        }

        Text
        {
            visible: !context.isRecorderPresent && context.isOutputSelection
            text: tr.Localize("SrcSelection_NoRecorderWarning");
        }

        Text
        {
            text: tr.Localize("SrcSelectionHint_"+context.outputDevice.toString(16));
            visible: !context.isRecorderPresent && context.isOutputSelection;
        }
    }
    Component.onCompleted:
    {
        outputDevSelection.itemAt(0).enabled = context.isRecorderPresent;
    }
}

