import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/HelpMapper.js" as HelpMapper

ActivationBasePage
{
	objectName: "activationPageFailed"
	Localizer { id:tr; scope:"LicenseManager" }
	headerString:		tr.Localize(context.ActivationPageFailed.IsError ? "ActivationResultLicenseExpiredHeader" : "ActivationResultSucceedHeader")
	nextButtonText:			tr.Localize("ButtonFinishText")
	helpButtonVisible: 	false

        function getHelpId()
	{
		return HelpMapper.ActivationPageFailedHelpId;
	}	
		
	Column
	{
		anchors.left:				parent.left
		anchors.right:				parent.right
		anchors.verticalCenter:		parent.verticalCenter
		AnimatedImage
		{
			anchors.horizontalCenter:		parent.horizontalCenter
            source:							"../common/images/license/" + (context.ActivationPageFailed.IsError ? "ico_warning_96.png" : "ico_ok_150.png")
		}
		Item {width: parent.width; height: 20 }
		Text
		{
			objectName: "errorText"
			horizontalAlignment:			Text.AlignHCenter
			property int margins: 			50
			anchors.left:					parent.left
			anchors.leftMargin:				margins
			anchors.rightMargin: 			margins
			anchors.right:					parent.right
			wrapMode:						Text.Wrap
			function prepareVariables()
			{
				var current = context.ActivationPageFailed;
				var variableMap = {
					"KeyFile" : current.KeyFile,
					"SystemErrorDescription" : tr.LocalizeOptional(current.SystemError, "Unknown", {"ErrorCode": current.ErrorCode}),
					"LicenseError" : tr.LocalizeOptional(current.LicenseError, "Unknown", {
						"OnlineActivationServerError" : tr.LocalizeOptional(current.OlaErrorCategory, "Unknown", {
							"OnlineActSrvError" : tr.LocalizeOptional(current.OlaError, "Unknown"),
							"OnlineActSrvErrorSpecific" : tr.LocalizeOptional(current.OlaErrorSpecific, "Unknown"),
							"OnlineActSrvErrorSpecificToInternetErrCodes" : tr.LocalizeOptional(current.OlaInternetError, "Unknown"),
							"OnlineActSrvErrorSpecificToServerErrCodes" : tr.LocalizeOptional(current.OlaServerError, "Unknown", {
								"OnlineActSrvError" : tr.LocalizeOptional(current.OlaError, "Unknown"),
								"OnlineActSrvErrorSpecific" : tr.LocalizeOptional(current.OlaErrorSpecific, "Unknown")
								})
						})
					}),
					"KeyInvalidReason" : tr.Localize(current.KeyInvalidReason, {"ProductName" : ProductTypeHelper.getProductName(tr, context)})
				};
				return variableMap;
			}
			text:							tr.Localize(context.ActivationPageFailed.ErrorCategory, prepareVariables())			
			font:							activationWizard.fontStyles.stateTextForActivationResult
		}
		Item {width: parent.width; height: 10 }
		Widgets.Hyperlink
		{
			objectName: "commonErrorLink"
            horizontalAlignment:			Text.AlignLeft
            anchors.horizontalCenter: parent.horizontalCenter
			text: tr.Localize("CommonTextForLinks")
			onClicked: Window.OpenURL(context.ActivationPageFailed.helpUrl)
			visible: context.ActivationPageFailed.IsErrorHelpUrlEnabled
		}
	}
	function onNext()
	{
		console.log("activationPageFailed::onNext(finished)");
		activationWizard.cancel();
	}
}

