import QtQuick 1.1
import "../common/widgets" as Widgets

Item
{
    id: featureBox
    signal activate(string panelName)
    objectName: "FeatureBox"
    property Item currentView: list
    property Item smallView:   list
    property Item hiddenView:  table
	property int tabOrder: 1
    width:  parent.width
    height: list.height

    property bool canUp: currentView == list && !animationRunning
    property bool canDown: currentView == table && !animationRunning
    property bool animationRunning: animation.running
	property bool toolViewOwnsFocus: false
    property bool hideTongue: false

	Connections
	{
		target: animation
		onRunningChanged: featureBox.animationRunning = animation.running;
	}
    function up()
    {
    	var hasFocus = list.activeFocus;
        doSwitch();
        doAnimation(true, true);
        if (hasFocus)
        	table.setActiveFocus();
    }

    function down()
    {
    	var hasFocus = table.activeFocus;
        doSwitch();
        doAnimation(false, false);
        if (hasFocus)
        	list.setActiveFocus();
    }

    SequentialAnimation
    {
        id: animation
        ScriptAction
        {
            id: preScript
            property bool enabled: true
            script:
            {
            	featureBox.animationRunning = true;
             	featureBox.toolViewOwnsFocus = toolViews.activeFocus;
                if (enabled)
                    setVisibility();
            }
        }
        NumberAnimation
        {
            id: animation1
        }
        NumberAnimation
        {
            id: animation2
        }
        ScriptAction
        {
            id: postScript
            property bool enabled: true
            script:
            {
                if (enabled)
                    setVisibility();

            	featureBox.animationRunning = false;

                if (featureBox.toolViewOwnsFocus)
                	featureBox.currentView.setActiveFocus;
            }
        }
    }

    function doSwitch()
    {
                var temp = currentView
        currentView = hiddenView
        hiddenView = temp
    }

    function empty()
    {
    }

    function setVisibility()
    {
        currentView.visible = true
        hiddenView.visible = false
    }

    function doAnimation(orderInverted, setVisibilityAtStart)
    {
        animation.running = false

        var heightAnimation = orderInverted ? animation2 : animation1
        var widthAnimation = orderInverted ? animation1 : animation2

        preScript.enabled = setVisibilityAtStart
        postScript.enabled = !setVisibilityAtStart

        heightAnimation.target = featureBox
        heightAnimation.property = "height"
        heightAnimation.from = height
        heightAnimation.to = currentView.height
        heightAnimation.duration = Math.abs(heightAnimation.from - heightAnimation.to) / 1.2
        widthAnimation.target = toolViews
        widthAnimation.property = "width"
        widthAnimation.from = toolViews.width
        widthAnimation.to = toolViews.currentWidth()
        widthAnimation.duration = Math.abs(widthAnimation.from - widthAnimation.to) / 1
        animation.running = true
    }

    FeatureBoxBackground
    {
        id: featureBoxBackround
        anchors {
            top: parent.top
            topMargin: 2
            bottom: greenBottom.top
            left: parent.left
            right: parent.right
        }
    }

    BorderImage
    {
        id: greenBottom
        anchors.bottom: parent.bottom
        anchors.left:   parent.left
        anchors.right:  parent.right
        border { left: 6; right: 6 }
        source: "../common/images/main_window/green_bottom.png"
        visible: innersView.opacity < 1
    }

    BottomTexture
    {
        anchors.fill: parent
        anchors.bottom: greenBottom.bottom
        anchors.topMargin: -2
    }

    Rectangle
    {
        id: firstBorder
        anchors.top: parent.top
        width: parent.width
        height: 1
        color: "#097f6d"
    }

    Rectangle
    {
        id: secondBorder
        anchors.top: firstBorder.bottom
        width: parent.width
        height: 1
        color: "#49b6a4"
    }

    Image
    {
        id: tongueUpGraphics
        objectName: "TongueUpGraphics"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.top
        anchors.bottomMargin: -23
        source: tongueUp.selectValue("", "../common/images/main_window/featurebox/tongue_up_normal.png", "../common/images/main_window/featurebox/tongue_up_hover.png", "../common/images/main_window/featurebox/tongue_up_pressed.png")
        visible: featureBox.canUp

        Widgets.BaseButton
        {
            id: tongueUp
            objectName: "tongueUp"
            tabOrder: 2
            focusRectEnabled: false
            setFocusOnPressed: !featureBox.toolViewOwnsFocus
            Widgets.FocusImage
            {
                width: sourceSize.width
                anchors {
                    top: parent.top
                    topMargin: 1
                    left: parent.left
                    leftMargin: 5
                }
                source: "../common/images/focuses/focus_featurebox_tongue.png"
            }

            anchors {
                fill: parent
                topMargin: 7
                bottomMargin: 4
                leftMargin: 10
                rightMargin: 10
            }

            enabled: !featureBox.animationRunning
            visible: featureBox.canUp
            onClicked: featureBox.up()
            onVisibleChanged:
            {
                if (tongueUp.visible && !featureBox.toolViewOwnsFocus)
                    tongueUp.forceActiveFocus();
            }
            Keys.onUpPressed:
            {
                tongueUp.clicked();
            }
        }
    }

    Item
    {
        objectName: "Clipper"
        anchors
        {
            fill: parent
            topMargin: -100 // don't clip at top - here is up button
            bottomMargin: 37 /* footer and separator */ - 15 /* bottom image */ + greenBottom.height
        }

        Item
        {
            objectName: "Corrector"
            anchors
            {
                fill: parent
                topMargin: 100 // correct y coordinate
            }

            Item
            {
                id: toolViewsWrapper
                objectName: "ToolViewsWrapper"
                height: parent.height
                width: parent.width
                anchors.left: parent.left
                clip: true

                Item
                {
                    id: toolViews
                    property int tabOrder: 1
                    objectName: "toolViews"
                    property real fullWidth: parent.width
                    property real widthWithLeftRight: parent.width - 31 * 2
                    function currentWidth()
                    {
                        return currentView.canLeft || currentView.canRight ? widthWithLeftRight : fullWidth;
                    }
                    anchors.horizontalCenter: parent.horizontalCenter
                    function updateFocusIndex(focusIndex)
                    {
                        if (focusIndex != list.focusIndex)
                            list.focusIndex = focusIndex
                        if (focusIndex != table.focusIndex)
                            table.focusIndex = focusIndex
                    }

                    ToolList
                    {
                        id: list
                        objectName: "toolList"
                        anchors.left:  parent.left
                        anchors.right: parent.right
                        onActivate: featureBox.activate(panelName)
                        onFocusIndexChanged: toolViews.updateFocusIndex(focusIndex);
                        Keys.onUpPressed:
                        {
                            if (event.modifiers & Qt.AltModifier)
                                featureBox.up();
                        }
                    }

                    ToolPanel
                    {
                        id: table
                        objectName: "toolPanel"
                        width: parent.width
                        visible: false
                        onActivate: featureBox.activate(panelName)
                        onFocusIndexChanged: toolViews.updateFocusIndex(focusIndex);
                        onCompressPanel: featureBox.down();
                    }
                    property bool activeFocus: list.activeFocus || table.activeFocus;
                    onActiveFocusChanged:
                    {
                        if (!featureBox.animationRunning)
                            featureBox.toolViewOwnsFocus = toolViews.activeFocus;
                    }
                    Component.onCompleted : width = currentWidth()
                }
            }

            Widgets.Button
            {
                objectName: "left"
                tabOrder: 2
                id: leftButton
                setFocusOnPressed: !featureBox.toolViewOwnsFocus
                iconImage: "../images/main_window/featurebox/arrow_left_normal.png"
                iconHoverImage: "../images/main_window/featurebox/arrow_left_hover.png"
                iconPressedImage: "../images/main_window/featurebox/arrow_left_pressed.png"
                iconDisabledImage: "../images/main_window/featurebox/arrow_left_disabled.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 7
                anchors.left: toolViewsWrapper.left
                anchors.leftMargin: -1
                enabled: !featureBox.animationRunning && currentView.canLeft
                visible: currentView == list
                mirror: Window.Mirror
                focusRectEnabled: false
                Widgets.FocusImage
                {
                    width: sourceSize.width
                    anchors {
                        top: parent.top
                        topMargin: 1
                        left: parent.left
                        leftMargin: 1
                    }
                    source: "../common/images/focuses/focus_featurebox_left.png"
                }

                onClicked:
                {
                	currentView.doLeft();
                	if (setFocusOnPressed && !enabled)
                		rightButton.forceActiveFocus();
                }
            }

            Widgets.Button
            {
                objectName: "right"
                id: rightButton
                setFocusOnPressed: !featureBox.toolViewOwnsFocus
                tabOrder: 3
                iconImage: "../images/main_window/featurebox/arrow_right_normal.png"
                iconHoverImage: "../images/main_window/featurebox/arrow_right_hover.png"
                iconPressedImage: "../images/main_window/featurebox/arrow_right_pressed.png"
                iconDisabledImage: "../images/main_window/featurebox/arrow_right_disabled.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 7
                anchors.right: toolViewsWrapper.right
                anchors.rightMargin: -1
                enabled: !featureBox.animationRunning && currentView.canRight
                visible: currentView == list
                mirror: Window.Mirror
                focusRectEnabled: false
                Widgets.FocusImage
                {
                    width: sourceSize.width
                    anchors {
                        top: parent.top
                        topMargin: 1
                        right: parent.right
                        rightMargin: 1
                    }
                    source: "../common/images/focuses/focus_featurebox_right.png"
                }

                onClicked:
                {
                	currentView.doRight();
                	if (setFocusOnPressed && !enabled)
                		leftButton.forceActiveFocus();
                }
            }
        }
    }

    Image
    {
        id: tongueDownGraphics
        objectName: "TongueDownGraphics"
        anchors.bottom: featureBox.top
        anchors.bottomMargin: -23
        anchors.horizontalCenter: featureBox.horizontalCenter
        source: tongueDown.selectValue("", "../common/images/main_window/featurebox/tongue_down_normal.png", "../common/images/main_window/featurebox/tongue_down_hover.png", "../common/images/main_window/featurebox/tongue_down_pressed.png")
        visible: featureBox.canDown && !featureBox.hideTongue

        Widgets.BaseButton
        {
            id: tongueDown
            tabOrder: 2
            focusRectEnabled: false
            setFocusOnPressed: !featureBox.toolViewOwnsFocus
            Widgets.FocusImage
            {
                anchors {
                    top: parent.top
                    topMargin: 1
                    left: parent.left
                    leftMargin: 5
                }
                source: "../common/images/focuses/focus_featurebox_tongue.png"
            }

            anchors {
                fill: parent
                topMargin: 7
                bottomMargin: 4
                leftMargin: 10
                rightMargin: 10
            }

            objectName: "tongueDown"
            enabled: !featureBox.animationRunning
            visible: featureBox.canDown
            onClicked: featureBox.down()
            onVisibleChanged:
            {
                if(tongueDown.visible && !featureBox.toolViewOwnsFocus)
                    tongueDown.forceActiveFocus();
            }
            Keys.onDownPressed: tongueDown.clicked();
        }
    }
}
