import QtQuick 1.1
import QtWebKit 1.0
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../main_window" as MainFrame
import "../common/EnumHelper.js" as EnumHelper
import "../common/DateTime.js" as DateTime
import "../common/HelpMapper.js" as HelpMapper

MainFrame.InnerContent
{
    Localizer { id:tr; scope:"NewsList" }
    caption: tr.Localize("NewsItem_Title", {"CurrentNewsIndex" : MainWindow.newsList.currentNewsIndex + 1, "NewsCount" : MainWindow.newsList.newsCount})
    property int helpId: HelpMapper.NewsItemHelpId
    objectName: "newsItem"
    property variant currentNews
    property variant currentIndex : MainWindow.newsList.currentNewsIndex;
    onCurrentIndexChanged: currentNews = MainWindow.newsList.GetCurrentNewsArticle();
    function showPage(page)
    {
        if (page != "")
            MainWindow.newsList.SetCurrentArticleById(page);
        else
            MainWindow.newsList.SetCurrentArticleFirstUnread();
        MainWindow.newsList.MarkCurrentArticleAsRead();
    }

    captionArea: Component
    {
        Item
        {
            property variant context: MainWindow.newsList
            objectName: "captionArea"

            Widgets.CaptionButton
            {
                id: nextButton
                objectName: "nextButton"
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: parent.right
                anchors.rightMargin: 8
                minWidth: 0
                iconImage: "../images/news/news_arrow_right.png"
                opacity: selectValue(0.5, 1, 1, 1)
                enabled: context.currentNewsIndex + 1 < context.newsCount && context.newsCount > 1;
                onClicked: {
                    context.currentNewsIndex++;
                    context.MarkCurrentArticleAsRead();
                }
                mirror: Window.Mirror
            }
            Widgets.CaptionButton
            {
                id: prevButton
                objectName: "prevButton"
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: nextButton.left
                anchors.rightMargin: 4
                minWidth: 0
                iconImage: "../images/news/news_arrow_left.png"
                opacity: selectValue(0.5, 1, 1, 1)
                enabled: context.currentNewsIndex > 0 && context.newsCount > 1;
                onClicked: {
                    context.currentNewsIndex--;
                    context.MarkCurrentArticleAsRead();
                }
                mirror: Window.Mirror
            }
        }
    }

    viewArea: Component
    {
        Item
        {
            property variant commonFontStyles: Fonts.Common{}
            property variant context: MainWindow.newsList

            Widgets.ScrollBar
            {
                id: scrollbar
                target: scrollView
                anchors.top: scrollView.top;
                anchors.right: parent.right;
                anchors.bottom: scrollView.bottom;
            }

            Flickable
            {
                id: scrollView

                anchors
                {
                    left: parent.left
                    top: parent.top
                    bottom: parent.bottom
                    right: scrollbar.left
                }

                contentHeight: content.url != undefined && content.url != "" ? container.y + container.height : parent.height
                contentWidth: width
                clip: true

                Widgets.StandardCaptionText
                {
                    id: title
                    anchors.top: parent.top
                    anchors.topMargin: 15
                    anchors.left: parent.left
                    anchors.leftMargin: 25
                    anchors.right: parent.right
                    anchors.rightMargin: 25
                    text: currentNews.title
                    wrapMode: Text.Wrap
                    horizontalAlignment: Text.AlignLeft
                }

                Item
                {
                    id: subTitle
                    height: 20
                    anchors.top: title.bottom
                    anchors.topMargin: 10
                    anchors.left: title.left;

                    Text
                    {
                        id: dateTime

                        color: "#7f7f7f"
                        text: DateTime.localizeDateTimeForNews(currentNews.dateTime, tr, " ");
                        font: commonFontStyles.standardCommonTextFont
                    }

                    Text
                    {
                        id: subTitleSeparator
                        text: "|"
                        font: dateTime.font
                        color: dateTime.color

                        anchors.left: dateTime.right
                        anchors.leftMargin: 5
                        anchors.verticalCenter: dateTime.verticalCenter
                        visible: EnumHelper.convert(currentNews, "importance",
                                                    {"Alert":true,
                                                     "Warning":true,
                                                     "Information":false});
                    }

                    BorderImage
                    {
                        id: statusIcon
                        anchors.left: subTitleSeparator.right
                        anchors.leftMargin: 7
                        anchors.verticalCenter: subTitleSeparator.verticalCenter
                        anchors.verticalCenterOffset: 1
                        height: 20
                        width: childrenRect.width + 30 - (childrenRect.width + 30) % 3

                        horizontalTileMode: BorderImage.Round
                        border {
                            top: 5
                            bottom: 4
                            left: 9
                            right: 12
                        }

                        source: EnumHelper.convert(currentNews, "importance",
                                    {"Alert":"../common/images/news/news_alert.png",
                                     "Warning":"../common/images/news/news_alert.png",
                                     "Information":""});
                        Text
                        {
                            anchors.centerIn: parent
                            anchors.verticalCenterOffset: -1
                            wrapMode: Text.Wrap
                            color: "white"
                            font: commonFontStyles.standardCommonTextFont
                            text:
                            {
                                return EnumHelper.convert(currentNews, "importance",
                                    {"Alert":tr.Localize("Alert"),
                                     "Warning":tr.Localize("Warning"),
                                     "Information":""});
                            }
                        }
                    }
                }

                Item
                {
                    // fix 138215 - container item for avoiding horizontal anchors in WebView
                    id: container
                    anchors.left: title.left
                    anchors.right: parent.right
                    anchors.rightMargin: 25
                    anchors.top: subTitle.bottom
                    anchors.topMargin: 10
                    height: content.height

                    Widgets.IpmWebView
                    {
                        id: content
                        width: parent.width
                        preferredWidth: width
                        url: currentNews.content
                        visible: url != undefined && url != ""
                        interop: context
                        Connections
                        {
                            target: context.IPM;
                            onParametersChanged: content.reload.trigger();
                        }

                        PropertyAnimation {
                             id: mouseWheelAnimation
                             target: scrollView
                             properties: "contentY"
                             duration: 500
                        }

                        MouseWheelArea
                        {
                            anchors.fill: parent

                            onVerticalWheel: {
                                var newContentY = Math.floor(
                                    (mouseWheelAnimation.running ? mouseWheelAnimation.to : scrollView.contentY) - delta);
                                var overshoot = 0;
                                if (newContentY < 0 )
                                {
                                    overshoot = -newContentY;
                                    newContentY = 0;
                                }
                                else if (newContentY >= scrollView.contentHeight - scrollView.height)
                                {
                                    overshoot = newContentY - scrollView.contentHeight + scrollView.height;
                                    newContentY = Math.max(0, scrollView.contentHeight - scrollView.height);
                                }
                                if (overshoot > 30)
                                    overshoot = 30;
                                mouseWheelAnimation.stop();
                                mouseWheelAnimation.to = newContentY;
                                mouseWheelAnimation.easing.type = overshoot > 0 ? Easing.OutBack : Easing.InOutQuad;
                                mouseWheelAnimation.easing.overshoot = overshoot / 12;
                                mouseWheelAnimation.start();
                            }
                        }
                    }
                }
            }
        }
    }
}
