import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/DateTime.js" as DateTime

ProblemListItemBase
{
	id: itemHolder
	objectName: itemModel.groupModel.isLicenseNotification ? "IPMLicenseNotification" : itemModel.title
	property variant itemModel: {}
	property variant localizer
	property variant actions: itemModel.actions || []

	canHaveFocus: actions.length > 0

	function localizeByProduct(key, params)
	{
		if(!key)
			return "";
		if(itemModel === undefined)
			return "";
		var postfix = ProductTypeHelper.getPostfixByProductType(MainWindow, "productType");
		var localizationKey = key;
		if(postfix != "")
			localizationKey += postfix;
		return localizer.LocalizeOptional(localizationKey, key, params);
	}

	function getFunctionalityDisabledAfterGrace()
	{
		switch (itemModel.groupModel.licenseProperties.licenseType)
		{
		case "LicenseTypeSubscriptionProtection":
			return localizer.Localize("FunctionalityDisabledForExpiredSubscriptionProtection");
		case "LicenseTypeSubscription":
			return localizer.Localize("FunctionalityDisabledForExpiredSubscription");
		default:
			return "";
		}
	}

    function getLicenseRemainingDaysCount()
    {
        return itemModel.groupModel.licenseProperties.licenseRemainingDaysCount;
    }

    function getSubscriptionOkHeaderDescription()
    {
        return itemModel.groupModel.licenseProperties.shouldShowSubscriptionRemainingDays ?
									localizer.Localize("SubscriptionRemainingDaysCount", {"LicenseRemainingDaysCount" : getLicenseRemainingDaysCount()}) :
									localizer.Localize("SubscriptionActivated");
    }

    Localizer { id:tr; scope:"LicenseManager" }

	function prepareVariables()
	{
		if(itemModel.groupModel != undefined)
		{
			switch(itemModel.groupModel.name)
			{
				case "AVBasesGroupName":
					return {
						"Update_PercentCompleted" : itemModel.groupModel.percentCompleted,
						"Update_Status" : localizer.Localize(itemModel.groupModel.updatingStatus)
					};
				case "ActiveThreatsGroupName":
					return {
						"ThreatName" : itemModel.groupModel.GetThreatName(itemModel.itemIndex),
						"ObjectName" : itemModel.groupModel.GetObjectName(itemModel.itemIndex)
					}
				case "RecommendationsGroupName":
					return {
						"AntispamTrainingHamLettersCountRequest" : itemModel.groupModel.antispamTrainingHamLettersCount,
						"AntispamTrainingSpamLettersCountRequest" : itemModel.groupModel.antispamTrainingSpamLettersCount
					}
				case "LicenseGroupName":
					return {
						"LicenseType" : tr.Localize(itemModel.groupModel.licenseProperties.licenseType),
						"LicensePcCount" : itemModel.groupModel.licenseProperties.licensePcCount,
						"LicenseLifespan" : DateTime.localizeTimeIntervalFromDaysCount(itemModel.groupModel.licenseProperties.licenseLifespanInDays, localizer),
						"LicenseRemainingDaysCount" : getLicenseRemainingDaysCount(),
						"LicenseGraceDaysCount" : itemModel.groupModel.licenseProperties.graceDaysCount,
						"LicensingStatusTrialRemain" : getLicenseRemainingDaysCount() != 0 ? 
							tr.Localize("LicenseRemain", {"LicenseRemainingDaysCount" : getLicenseRemainingDaysCount()}) :
							tr.Localize("LicenseEndsToday"),
						"FunctionalityDisabledAfterGrace" : getFunctionalityDisabledAfterGrace(),
						"FunctionalityLevelDescription" : localizer.Localize(itemModel.groupModel.licenseProperties.protectionLevelDescription) + localizer.Localize(itemModel.groupModel.licenseProperties.updaterLevelDescription),
                        "SubscriptionExpirationDate" : localizer.LocalizeDateTimeShort(itemModel.groupModel.licenseProperties.expirationDate),
						"SubscriptionOkHeaderDescription" : getSubscriptionOkHeaderDescription(),
						"StateOkSubscriptionText" : localizer.Localize(itemModel.groupModel.licenseProperties.stateOkSubscriptionText, {
                            "SubscriptionExpirationDate" :localizer.LocalizeDateTimeShort(itemModel.groupModel.licenseProperties.expirationDate)
							}),
						"ReserveCode" : itemModel.groupModel.licenseProperties.reserveCodeUnmasked,
						"PreinstalledCode" : itemModel.groupModel.licenseProperties.preinstalledCode,
						"ProductName" : ProductTypeHelper.getProductName(tr, itemModel.groupModel),
						"ProductNameFull" : ProductTypeHelper.getProductNameFull(tr, itemModel.groupModel)
					}
				default:
			};
		}
		return {};
	}

    Text
    {
        font: commonFontStyles.standardSectionCaptionFont
        text: itemHolder.localizer.Localize(itemModel.groupModel.name)
        color: "#969696"
        anchors.left: parent.left
        anchors.leftMargin: 15
        anchors.top: parent.top
        anchors.topMargin: 9
    }

	Rectangle
	{
		color: style.itemColor
		border.color: style.itemBorderColor
		anchors.fill: parent
        objectName: "itemRect"
		// http://bugreports.qt.nokia.com/browse/QTBUG-14847
		// AnimatedImage does not use pixmap cache, so we use AnimatedImage only if really needed
		Row
		{
			id: stateIcon
            anchors.left: parent.left; anchors.leftMargin: 32
            anchors.top: textGroup.top; anchors.topMargin: 9
			
			Image 
			{
				visible: itemModel.problemState != 3
				source: {
					switch (itemModel.problemState)
					{
						case 0: return Qt.resolvedUrl("../common/images/ico_info_32.png");
						case 1: return Qt.resolvedUrl("../common/images/ico_warning_32.png");
						case 2: return Qt.resolvedUrl("../common/images/ico_danger_32.png");
						default: ''
					}
				}
			}
			
			AnimatedImage 
			{
				visible: itemModel.problemState == 3
				source: itemModel.problemState == 3 ? Qt.resolvedUrl("../common/images/loader_32.gif"): ''
			}		
		}
		
		
		Item
		{
            id: textGroup
            anchors.left: stateIcon.right;
            anchors.leftMargin: 27
			anchors.right: itemActions.left;
            anchors.rightMargin: 10
			property int textGap: 5
			anchors.verticalCenter: parent.verticalCenter
			anchors.verticalCenterOffset: -2
            height: titleText.height + textGap + descriptionText.height;
            // title text

			Text
			{
				id: titleText
				anchors.left:parent.left;
				anchors.right: parent.right;			
				anchors.top: parent.top;

				font: commonFontStyles.standardSmallCaptionFont
				text: itemModel.groupModel.isLicenseNotification ? itemModel.title :
					itemHolder.localizeByProduct(itemModel.title, itemHolder.prepareVariables());
				wrapMode: Text.Wrap
				maximumLineCount: 2
				elide: Text.ElideRight

				horizontalAlignment: Text.AlignLeft

				onTextChanged:
				{
					if (itemModel != undefined &&
					    itemModel.groupModel != undefined &&
					    itemModel.groupModel.IPM != undefined &&
						itemModel.groupModel.name == "LicenseGroupName" &&
					    itemModel.groupModel.isLicenseNotification)
						itemModel.groupModel.IPM.reportShowStatistics();
				}
			}
			// description text
			Text
			{
				id:descriptionText
				anchors.left:parent.left;
				anchors.right:parent.right;
				anchors.top: titleText.bottom; anchors.topMargin: parent.textGap

				wrapMode: itemModel.isDescriptionMultiline ? Text.WordWrap : Text.NoWrap
				horizontalAlignment: Text.AlignLeft
				font: commonFontStyles.standardCommonTextFont
				color: "black";
				//text: itemModel.description
				text: itemModel.groupModel.isLicenseNotification ? itemModel.description :
					itemHolder.localizeByProduct(itemModel.description, itemHolder.prepareVariables());
				elide: itemModel.isDescriptionMultiline ? Text.ElideNone : Text.ElideMiddle
			}
        }

        Rectangle
        {
            anchors.bottom: parent.bottom
            width: parent.width
            height: 1
            color: "#e7e7e7"
        }
		
		// actions
		Item
		{
			id: itemActions
			objectName: "itemActions"
            anchors.right: parent.right;
            anchors.rightMargin: 15
            height: parent.height
            width: 130
			Widgets.DPIScaler{changeWidth:true}
			visible: itemHolder.actions.length > 0

			Widgets.ComboButton
			{
				objectName: "action"
				actionList: itemHolder.actions
                minWidth: parent.width
                maxWidth: parent.width
                width: parent.width
                anchors.verticalCenter: parent.verticalCenter;
				property QtObject tempElement
				focus: true
				tabOrder: 0;
                enabled: !itemModel.areActionsDisabled
                localizer: itemHolder.localizer
				onPressed:
				{
					if(index < actionList.length)
					{
						tempElement = actionList[index];
						if (tempElement.action != undefined)
							tempElement.action.Invoke(itemModel.itemIndex)
					}
                }
			}
		}
	}
}

