import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/EnumHelper.js" as EnumHelper
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets
import "../common/Colors.js" as Colors

Rectangle
{
	id: backView
	objectName: "backView"
    property string backgroundColor: "transparent"
	property string buttonImage: "../images/widgets/key_gray.png"
	property variant commonFontStyles: Fonts.Common{}
    border.color: Colors.grayBorder
    color: "transparent"
    radius: 5
    
    Localizer { id:tr; scope:"ScanTask" }

    Keys.onEscapePressed: setFrontPosition();

	function setActiveFocus()
	{
		if (stopMessageBox.visible)
			stopMessageBox.setActiveFocus();
		if (resumeMessageBox.visible)
			resumeMessageBox.setActiveFocus();
	}

	Widgets.EmbeddedMessageBox
	{
		objectName:		"StopMessageBox"
		id: stopMessageBox
		width:			parent.width
		height:			parent.height
		color:			askPanel.backgroundColor
		font:	 		commonFontStyles.standardBoldSubHeadingFont
		text:				scan.askStopScan
		leftButtonText:		tr.Localize("YesButtonText")
		rightButtonText:	tr.Localize("NoButtonText")
		leftButtonObjectName: "YesButton"
		rightButtonObjectName: "NoButton"
		buttonsWidth:		120
		buttonsHeight:		34

		onLeftClicked:
		{
			setFrontPosition()
			scan.contextScan.Stop()
		}
		onRightClicked:
		{
			setFrontPosition()
		}

		visible: askPanel.state == "askStopScan"
	}
        Widgets.EmbeddedMessageBox
	{
		objectName:		"ResumeMessageBox"
		id: resumeMessageBox
		width:			parent.width
		height:			parent.height
		color:			askPanel.backgroundColor
		font:	 		commonFontStyles.standardBoldSubHeadingFont
		text:				scan.askResumeScan
		leftButtonText:		tr.Localize("AcceptResumeButtonText")
		rightButtonText:	tr.Localize("RejectResumeButtonText")
		leftButtonObjectName: "AcceptButton"
		rightButtonObjectName: "RejectButton"
		buttonsWidth:		140
		buttonsHeight:		34

		onLeftClicked:
		{
			setFrontPosition()
			scan.contextScan.Resume()
		}
		onRightClicked: startScan()

		visible: askPanel.state == "askResumeScan"
	}
	states:
	[
		State
		{
			name: "askStopScan"
		},
		State
		{
			name: "askResumeScan"
		}
	]
}
