import QtQuick 1.1
import "../common/widgets" as Widgets

Item
{
    id: groupTabs
    property variant model
    property variant currentGroup: model ? groupView.currentItem.group : undefined
    width: 204
    height: tabbarImage.height
    BorderImage
    {
        id: tabbarImage
        width: parent.width
        smooth: true
        source: "../common/images/settings/tabbar.png"
        border { left: 15; right: 15 }
        Widgets.DPIScaler { changeHeight: true }
    }

    function selectGroup(name)
    {
        var index = groupIndexFromName(name);
        if (index == -1)
        {
            console.log("group " + name + " not found")
            return
        }
        groupView.currentIndex = index;
    }

    function groupIndexFromName(name)
    {
        for (var i in model)
        {
            if (model[i].Name == name)
                return i;
        }
        return -1;
    }

    Component
    {
        id: groupListItem
        Widgets.BaseButton
        {
            id: tabButton
            objectName: group.Name
            width: tabButtonHover.width
            height:  tabButtonHover.height
            property variant group: model.modelData                        
            focusRectEnabled: false
            Widgets.FocusImage
            {
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
                tileHorizontally: true
                tileVertically: true
                widthClipperSize: 4
                border {
                    top: 13
                    bottom: 10
                    left: 13
                    right: 15
                }
                source: "../common/images/focuses/focus_footer_secondary.png"
            }

            Image
            {
                id: tabButtonHover
                smooth: true
                visible: tabButton.state == "hover"
                source: "../common/images/settings/tab_hover.png"

                Widgets.DPIScaler { changeSize: true }
            }
            Image
            {
                anchors.centerIn: parent
                smooth: true
                source: "../common/images/settings/groups/" + group.Name + ".png"

                Widgets.DPIScaler { changeSize: true }
            }

            onClicked: ListView.view.currentIndex = index
            Keys.onUpPressed:
            {
                if (ListView.view.currentIndex > 0)
                    ListView.view.currentIndex--;
            }
            Keys.onDownPressed:
            {
                if (ListView.view.currentIndex < (ListView.view.count - 1))
                    ListView.view.currentIndex++;
            }
        }
    }

    ListView
    {
        id: groupView
        objectName: "GroupList"
        orientation: ListView.Horizontal
        anchors.left: parent.left
        anchors.top: parent.top
        height: tabbarImage.height
        width: count ? count * currentItem.width : 0
        model: groupTabs.model
        delegate: groupListItem
        highlight: Image {
            smooth: true
            source: "../common/images/settings/tab_selected.png"

            Widgets.DPIScaler { changeSize: true }
        }
        interactive: false
        focus: true
    }

    Keys.onLeftPressed: groupView.decrementCurrentIndex();
    Keys.onRightPressed: groupView.incrementCurrentIndex();

    Widgets.DPIScaler { changeSize: true }
}
