import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "ReportsAndQuarantinePage"

    property int helpId: HelpMapper.ReportsAndQuarantineSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "ReportsAndQuarantine")
    property variant fontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "ReportsAndQuarantineSettings" }

    Column
    {
        width: parent.width
        height: parent.height
        spacing: Margins.settingsPageSpacing
        objectName: "ReportsColumn"

        SettingsCommon.SettingsSection
        {
            objectName: "ReportsAndQuarantineGeneralSection"
            body: Column
            {
                objectName: "ReportsAndQuarantineGeneral"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                SettingsCommon.CheckBox
                {
                    id: useReports
                    anchors.left: parent.left
                    objectName: "FullReport"
                    text: tr.Localize("FullReport")
                    isBold: true

                    target: context
                    property: "fullLog"
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            id: storingReports
            objectName: "StoringReports"
            name: tr.Localize("StoringReports")

            body: Column
            {
                width: parent.width
                objectName: "StoringReportsColumn"
                spacing: Margins.settingsSectionInnerSpacing
                property int maxWidth

                Item
                {
                    objectName: "Row"
                    anchors.left: parent.left
                    height: childrenRect.height
                    width: parent.width

                    SettingsCommon.CheckBox
                    {
                        id: storingReportsTimeLimit
                        objectName: "StoringReportsTimeLimit"
                        anchors.left: parent.left
                        height: storingReportsTimeLimitSpin.height

                        text: tr.Localize("StoringReportsTimeLimit")

                        target: context
                        property: "logPeriodOn"
                    }

                    Widgets.IntSpinEdit
                    {
                        id: storingReportsTimeLimitSpin
                        objectName: "StoringReportsTimeLimitSpin"

                        anchors.left: storingReportsTimeLimit.right
                        anchors.leftMargin: Margins.settingsBeforeSpinEdit
                        anchors.verticalCenter: storingReportsTimeLimit.verticalCenter
                        anchors.verticalCenterOffset: 2

                        enabled: context.logPeriodOn
                        minValue: 1
                        maxValue: 10000

                        target: context
                        property: "logPeriodValue"
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        anchors.left: storingReportsTimeLimitSpin.right
                        anchors.leftMargin: Margins.settingsAfterSpinEdit
                        anchors.verticalCenter: storingReportsTimeLimitSpin.verticalCenter

                        text: tr.Localize("Days")
                        color: context.logPeriodOn ? "black" : "grey"
                    }
                }

                Item
                {
                    objectName: "Row"
                    anchors.left: parent.left
                    height: childrenRect.height
                    width: parent.width

                    SettingsCommon.CheckBox
                    {
                        id: storingReportsSizeLimit
                        height: storingReportsSizeLimitSpin.height

                        objectName: "StoringReportsSizeLimit"
                        anchors.left: parent.left
                        text: tr.Localize("StoringReportsSizeLimit")

                        target: context
                        property: "logSizeOn"
                    }

                    Widgets.IntSpinEdit
                    {
                        id: storingReportsSizeLimitSpin
                        enabled: context.logSizeOn
                        objectName: "StoringReportsSizeLimitSpin"

                        anchors.left: storingReportsSizeLimit.right
                        anchors.leftMargin: Margins.settingsBeforeSpinEdit
                        anchors.verticalCenter: storingReportsSizeLimit.verticalCenter
                        anchors.verticalCenterOffset: 2

                        minValue: 50
                        maxValue: 4000

                        target: context
                        property: "logSizeValue"
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        anchors.left: storingReportsSizeLimitSpin.right
                        anchors.leftMargin: Margins.settingsAfterSpinEdit
                        anchors.verticalCenter: storingReportsSizeLimitSpin.verticalCenter

                        text: tr.Localize("MBSuffix")
                        color: context.logSizeOn ? "black" : "grey"
                    }
                }

                Component.onCompleted:
                {
                    var maxWidth = Math.max(storingReportsSizeLimit.width, storingReportsTimeLimit.width);
                    storingReportsSizeLimitSpin.anchors.leftMargin += (maxWidth - storingReportsSizeLimit.width)
                    storingReportsTimeLimitSpin.anchors.leftMargin += (maxWidth - storingReportsTimeLimit.width)
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            id: cleaningReports
            objectName: "CleaningReports"
            name: tr.Localize("CleaningReports")
            smallBottomMargin: true

            body: Column
            {
                width: parent.width
                objectName: "CleaningReportsColumn"
                spacing: Margins.settingsAfterTextSpacing

                SettingsCommon.SettingsStandardText
                {
                    anchors.left: parent.left
                    width: parent.width
                    text: tr.Localize("ChooseReportsToClean")
                    wrapMode: Text.Wrap
                }

                SettingsCommon.SettingsButton
                {
                    objectName: "CleanReports"
                    anchors.left: parent.left
                    text: tr.Localize("CleanReports")
                    onClicked: context.CleanReports()
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            id: storingQuarantine
            objectName: "StoringQuarantine"
            name: tr.Localize("StoringQuarantine")
            property int maxWidth

            body: Column
            {
                width: parent.width
                objectName: "StoringQuarantineColumn"
                spacing: Margins.settingsSectionInnerSpacing

                Item
                {
                    objectName: "Row"
                    height: childrenRect.height
                    width: parent.width

                    SettingsCommon.CheckBox
                    {
                        id: storingQuarantineTimeLimit
                        anchors.left: parent.left
                        height: storingQuarantineTimeLimitSpin.height

                        objectName: "StoringQuarantineTimeLimit"
                        text: tr.Localize("StoringQuarantineTimeLimit")

                        target: context
                        property: "quarantinePeriodOn"
                    }

                    Widgets.IntSpinEdit
                    {
                        id: storingQuarantineTimeLimitSpin
                        enabled: context.quarantinePeriodOn
                        objectName: "StoringQuarantineTimeLimitSpin"

                        anchors.left: storingQuarantineTimeLimit.right
                        anchors.leftMargin: Margins.settingsBeforeSpinEdit
                        anchors.verticalCenter: storingQuarantineTimeLimit.verticalCenter
                        anchors.verticalCenterOffset: 2

                        minValue: 1
                        maxValue: 10000

                        target: context
                        property: "quarantinePeriodValue"
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        anchors.left: storingQuarantineTimeLimitSpin.right
                        anchors.leftMargin: Margins.settingsAfterSpinEdit
                        anchors.verticalCenter: storingQuarantineTimeLimitSpin.verticalCenter

                        text: tr.Localize("Days")
                        color: context.quarantinePeriodOn ? "black" : "grey"
                    }
                }

                Item
                {
                    objectName: "Row"
                    anchors.left: parent.left
                    height: childrenRect.height
                    width: parent.width

                    SettingsCommon.CheckBox
                    {
                        id: storingQuarantineSizeLimit

                        objectName: "StoringQuarantineSizeLimit"
                        anchors.left: parent.left
                        height: storingQuarantineSizeLimitSpin.height
                        text: tr.Localize("StoringQuarantineSizeLimit")

                        target: context
                        property: "quarantineSizeOn"
                    }

                    Widgets.IntSpinEdit
                    {
                        id: storingQuarantineSizeLimitSpin
                        enabled: context.quarantineSizeOn
                        objectName: "StoringQuarantineSizeLimitSpin"

                        anchors.left: storingQuarantineSizeLimit.right
                        anchors.leftMargin: Margins.settingsBeforeSpinEdit
                        anchors.verticalCenter: storingQuarantineSizeLimit.verticalCenter
                        anchors.verticalCenterOffset: 2

                        minValue: 50
                        maxValue: 4000

                        target: context
                        property: "quarantineSizeValue"
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        anchors.left: storingQuarantineSizeLimitSpin.right
                        anchors.leftMargin: Margins.settingsAfterSpinEdit
                        anchors.verticalCenter: storingQuarantineSizeLimitSpin.verticalCenter

                        text: tr.Localize("MBSuffix")
                        color: context.quarantineSizeOn ? "black" : "grey"
                    }
                }

                Component.onCompleted:
                {
                    var maxWidth = Math.max(storingQuarantineSizeLimit.width, storingQuarantineTimeLimit.width);
                    storingQuarantineTimeLimitSpin.anchors.leftMargin += (maxWidth - storingQuarantineTimeLimit.width)
                    storingQuarantineSizeLimitSpin.anchors.leftMargin += (maxWidth - storingQuarantineSizeLimit.width)
                }
            }
        }
    }
}
